@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

//@mixin instagram--md() {
@media #{$media_md} {
    /* Widget: Instagram */
	.widget_instagram_images_columns_5 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_6 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_7 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_8 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_9 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_10 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_11 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_12 .widget_instagram_images_item_wrap {
		width: 25%;
	}
}

//@mixin instagram--xs() {
@media #{$media_xs} {
    /* Widget: Instagram */
	.widget_instagram_images_columns_3 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_4 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_5 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_6 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_7 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_8 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_9 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_10 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_11 .widget_instagram_images_item_wrap,
	.widget_instagram_images_columns_12 .widget_instagram_images_item_wrap {
		width: 50%;
	}
}
