/* Importer
-----------------------------------------------------------------*/
.trx_importer {
  overflow: hidden;
}

.trx_importer_section,
.trx_exporter_section,
.trx_banners_section {
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.trx_importer_section {
  width: 48%;
  float: left;
  border: 1px solid #e0e2e5;
  margin: 2em 0 0 0;
  padding: 1em 2em 2em;
}

.trx_importer_section:after {
  content: ' ';
  display: block;
  width: 100%;
  height: 0;
  clear: both;
}

.trx_exporter_section {
  width: 48%;
  float: right;
  border: 1px solid #e0e2e5;
  margin: 2em 2em 0 0;
  padding: 1em 2em 2em;
}

.trx_banners_section {
  width: 48%;
  float: right;
  margin: 2em 2em 0 0;
}

.trx_importer + .trx_banners_section .trx_banners_item {
  font-size: 1.25em;
  line-height: 1.5em;
}

.trx_addons_tabs_section .trx_importer_section,
.trx_addons_tabs_section .trx_exporter_section {
  margin: 0;
  width: 100%;
  float: none;
  border: none;
  padding: 0;
  overflow: hidden;
}

.trx_addons_tabs_section .trx_exporter_section {
  border-bottom: 1px solid #e0e2e5;
  margin-bottom: 2em;
  padding-bottom: 2em;
}

.trx_addons_tabs_section .trx_banners_section {
  width: 48%;
  float: right;
  margin: 0 0 2em;
}

.trx_addons_tabs_section #trx_importer_progress {
  width: 48%;
  float: left;
}

.trx_addons_tabs_section #trx_importer_form > p:first-child {
  margin-top: 0;
}

@media (max-width: 1023px) {
  .trx_importer_section,
  .trx_exporter_section,
  .trx_banners_section {
    width: 98% !important;
    float: none;
    margin-left: 0 !important;
    margin-right: 0 !important;
  }

  .trx_banners_section {
    margin-bottom: 2em !important;
  }

  .trx_exporter_section {
    margin-bottom: 2em;
  }

  .trx_addons_tabs_section #trx_importer_progress,
  .trx_addons_tabs_section .trx_banners_section {
    width: 100%;
    float: none;
  }
}
.trx_exporter_error {
  padding-top: 1em;
  padding-bottom: 1em;
  margin: 1em 0;
}

#trx_importer_form .import_posts_params {
  display: block;
  margin-top: 0.5em;
}

.trx_importer_hidden {
  display: none;
}

#trx_importer_form {
  width: 48%;
}

.trx_importer_demo_set .trx_importer_demo_set_controls {
  border-bottom: 1px solid #e0e2e5;
}

.trx_importer_demo_set .trx_importer_demo_set_controls label {
  display: inline-block;
  vertical-align: top;
  border: 1px solid #dee0e3;
  border-bottom: none;
  color: #23282d;
  background-color: #ebeced;
  padding: 15px;
  text-align: center;
  position: relative;
  top: 1px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: background-color color ease;
  -ms-transition: background-color color ease;
  transition: background-color color ease;
}

.trx_importer_demo_set .trx_importer_demo_set_controls label:not(:last-child) {
  border-right: 0;
}

.trx_importer_demo_set .trx_importer_demo_set_controls label:hover {
  background-color: #e1e2e3;
}

.trx_importer_demo_set .trx_importer_demo_set_controls label.trx_importer_demo_set_active {
  background-color: #fff;
  border-top: 3px solid #11a0d2;
  padding-top: 13px;
}

.trx_importer_demo_set .trx_importer_demo_set_controls label input[type="radio"] {
  display: none;
}

.trx_importer_description {
  margin-top: 2em;
}

.trx_importer_separator {
  margin-bottom: 1em;
}

.trx_importer_separator_before {
  margin-top: 1em;
}

.trx_importer .trx_buttons {
  margin-top: 1em;
}

.trx_importer li {
  margin-top: 0;
  margin-bottom: 0;
}

.trx_importer label {
  display: block;
}

.trx_importer_part_pages {
  max-height: 15em;
  overflow-y: scroll;
  overflow-x: hidden;
  margin: 0 0 1em 2em;
  display: inline-block;
  vertical-align: top;
  padding-left: 2px;
}

.trx_importer_item_description {
  padding: 2px 0 10px 25px;
}

.trx_importer_subtitle {
  font-weight: 600;
  margin: 0 0 1em;
}

.trx_importer_advanced_settings {
  margin: 0 0 2em;
}

.trx_importer_advanced_settings_block {
  display: inline-block;
  vertical-align: top;
  width: 50%;
  box-sizing: border-box;
  padding-right: 3em;
}

.trx_importer_advanced_settings_block:last-child {
  padding-right: 0;
}

@media (max-width: 1439px) {
  .trx_importer_advanced_settings_block {
    display: block;
    width: 100%;
    padding-right: 0;
  }

  .trx_importer_advanced_settings_block + .trx_importer_advanced_settings_block {
    margin-top: 2em;
  }
}
#trx_importer_progress {
  display: none;
  margin: 0 0 2em;
  background-color: #f8f8f9;
  border: 1px solid #e7e9ec;
  border-left: 4px solid #11a0d2;
}
#trx_importer_progress table {
  margin: 1em;
}
#trx_importer_progress .import_progress_status {
  background-position: 20px center;
  background-repeat: no-repeat;
}
#trx_importer_progress .import_progress_status {
  text-align: left;
  background-size: 15px 15px;
  padding-left: 20px;
  padding-bottom: 6px;
  min-width: 5em;
}
#trx_importer_progress .import_progress_status.step_in_progress {
  background-image: url(images/ajax-loader.gif);
  padding-left: 40px;
}
#trx_importer_progress .import_progress_status:before {
  font-family: 'trx_addons_icons';
  display: inline-block;
  vertical-align: top;
  margin-right: 0.5em;
}
#trx_importer_progress .import_progress_status.step_complete:before {
  content: '\e878';
  color: #38bb7a;
}
#trx_importer_progress .import_progress_status.step_complete_with_error:before {
  content: '\e924';
  color: #f04c49;
}
#trx_importer_progress .trx_importer_progress_result {
  display: none;
  font-size: 1em;
  line-height: 1.5em;
  font-weight: normal;
  margin: 1.25em;
}
#trx_importer_progress .trx_importer_progress_result_msg,
#trx_importer_progress .trx_importer_progress_result_msg .error_message {
  display: block;
}
#trx_importer_progress .trx_importer_progress_result_msg .error_message:before {
  content: '- ';
}
#trx_importer_progress .trx_importer_progress_complete {
  color: #129611;
}
#trx_importer_progress .trx_importer_progress_error {
  color: #961211;
}
#trx_importer_progress .trx_importer_view_site {
  display: block;
  margin-top: 1em;
}

/* System Info */
.trx_importer_sys_info {
  width: 48%;
  max-width: 500px;
  float: right;
  color: #9099a2;
}
.trx_banners_section:not(.trx_addons_hidden) + .trx_importer_sys_info {
  display: none;
}
.trx_importer_sys_info code {
  color: #555d66;
}
.trx_importer_sys_info a {
  color: #11a0d2;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.trx_importer_sys_info a:hover {
  color: #0280ac;
}
.trx_importer_sys_info .dashicons {
  font-size: 1.25em;
  position: absolute;
  z-index: 1;
  top: 3px;
  left: -1.3em;
  color: #11a0d2;
}
.trx_importer_sys_info .trx_importer_sys_info_manual_title {
  text-align: left;
  font-size: 1.1em;
  font-weight: 600;
  color: #555d66;
  margin: 0 0 0.75em;
  position: relative;
}
.trx_importer_sys_info .trx_importer_sys_info_manual li {
  margin-top: 0.5em;
}

@media (max-width: 767px) {
  #trx_importer_form,
  .trx_importer_sys_info {
    display: block;
    width: 100%;
    padding: 0;
    margin: 0;
    max-width: none;
    float: none;
  }

  .trx_importer_sys_info {
    margin: 2em 0;
  }
}

/*# sourceMappingURL=importer.css.map */
