@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

.sc_users_columns_wrap {
	@include flex;
	@include flex-wrap(wrap);
}
.sc_users_slider .sc_users_item,
.sc_users_columns_wrap .sc_users_item {
	display:inline-block;
	vertical-align:top;
	@include box(100%, 100%);
	@include border-box;
}
.sc_users_slider .sc_users_item {
	margin-bottom: 0 !important;
}

.sc_users {
	position: relative;	
}
.sc_users .sc_users_item_thumb[class*="hover_"] {
	display: block !important;
	margin-bottom: 0;
}

.sc_users .sc_users_item_thumb .sc_users_item_link {
	@include abs-cover(2);
}


/* Style 'Default' */
.sc_users_default .sc_users_item {
	background-color:#fafafa;
	margin-bottom: 2em;
}
.sc_users_default.slider_swiper .sc_users_item,
.sc_users_default .columns_padding_bottom .sc_users_item {
	margin-bottom:0;
}

.sc_users_default .sc_users_item_thumb {
	position: relative;
	display: block !important;
	margin-bottom:0;

	img {
		width: 100%;
	}
	.sc_users_item_link {
		@include abs-cover;
		z-index: 0;
	}
}

.sc_users_default .sc_users_item_info {
	padding: 2.6em 3em;
	text-align:center;
}

.sc_users_default .sc_users_item_title,
.sc_users_short .sc_users_item_title,
.sc_users_featured .sc_users_item_title {
	margin: 0;
}
.sc_users_default .sc_users_item_subtitle {
	@include font(13px, 20px, '', italic);
	letter-spacing:0;
	margin-top:1px;
}

.sc_users_default .sc_users_item_content {
	margin-top: 1.5em;
	margin-bottom: 1.5em;
}
.sc_users_default .sc_users_item_content p {
	margin: 0;
}

.sc_users_default .sc_users_item_socials {
	margin: 1.5em 0 0;
}
.sc_users_default .sc_users_item_socials .social_item {
	display:inline-block;
	margin: 0 3px 3px 0;
}
.sc_users_default .sc_users_item_socials .social_item .social_icon {
	display:block;
	@include square(3em);
}

.sc_users_default .sc_users_item_button {
	margin:1.6em 0 0;
	display:none;
}

.sc_users_default .trx_addons_hover_content .trx_addons_hover_title {
	font-size: 1.3333em;
}


/* Style 'List' */
.sc_users_list .sc_users_item {
	@include flex;
	@include flex-direction(row);
	@include flex-justify-content(flex-start);
	@include flex-align-items(center);
	margin-bottom: 1em;
}
.sc_users_list .sc_users_item:last-child,
.sc_users_list.slider_swiper .sc_users_item,
.sc_users_list .columns_padding_bottom .sc_users_item {
	margin-bottom:0;
}
.sc_users_list .sc_users_item_thumb {
	@include square(4em);
	@include border-round;
	overflow: hidden;

	.mask,
	.icons {
		display: none !important;
	}
}
.sc_users_list .sc_users_item_thumb + .sc_users_item_info {
	margin-left: 1.5em;
}
.sc_users_list .sc_users_item_title {
	@include font(1.15em, 1.5em);
	letter-spacing:0;
	margin: 0;
}
.sc_users_list .sc_users_item_subtitle {
	@include font(13px, 20px, '', italic);
	letter-spacing:0;
	margin-top:1px;
}
.sc_users_list .sc_users_item_content {
	margin: 1em 0 0;
	display:none;
}
.sc_users_list .sc_users_item_socials {
	margin: 0;
}
.sc_users_list .sc_users_item_socials .social_item {
	display:inline-block;
	margin: 0 8px 0 0;
}
.sc_users_list .sc_users_item_socials .social_item .social_icon {
	display: inline-block;
	width: auto;
	height: auto;
	line-height: inherit;
	padding: 0;
	background-color: transparent !important;
}
.sc_users_list .sc_users_item_button {
	margin:1em 0 0;
	display:none;
}
