/* Google Reviews */
.properties_page_google_reviews_details {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: space-between;
  -ms-flex-pack: space-between;
  justify-content: space-between;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}

.properties_page_google_reviews_title {
  margin: 0 0 0.5em;
}

.properties_page_google_reviews_button_add_review {
  margin-top: 1em;
}

.properties_page_google_reviews_button_view_all {
  margin-top: 2em;
}

.properties_page_google_reviews_info {
  width: 31%;
}
.properties_page_google_reviews_info .properties_page_google_reviews_icon {
  width: 1.5em;
  height: 1.5em;
  line-height: 1.5em;
  text-align: center;
  margin-right: 0.5em;
  display: inline-block;
  vertical-align: middle;
}
.properties_page_google_reviews_info .properties_page_google_reviews_icon img {
  max-height: 100%;
  width: auto;
}
.properties_page_google_reviews_info .properties_page_google_reviews_info_list_caption {
  font-weight: 500;
  display: inline-block;
  vertical-align: top;
  margin-right: 0.5em;
}

.properties_page_google_reviews_rating {
  width: 31%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.properties_page_google_reviews_list {
  width: 31%;
}

.properties_page_google_reviews_authors {
  list-style-type: none;
  margin: 0;
  padding: 0;
}
.properties_page_google_reviews_authors li {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  position: relative;
  padding-left: 4em;
  margin-bottom: 1.5em;
  padding-bottom: 1.5em;
  border-bottom: 1px dotted #888;
}
.properties_page_google_reviews_authors li:before {
  display: none;
}
.properties_page_google_reviews_authors li:last-child {
  margin-bottom: 0;
  padding-bottom: 0;
  border-bottom: none;
}

.properties_page_google_reviews .sc_item_slider.slider_outer_controls_top > .slider_controls_wrap {
  top: -4em;
}

.properties_page_google_reviews_author_data {
  width: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  position: relative;
  padding-left: 4em;
}
.properties_page_google_reviews_author_data p {
  margin: 0;
}
.properties_page_google_reviews_author_data .properties_page_google_reviews_author_photo {
  width: 3em;
  height: 3em;
  line-height: 3em;
  text-align: center;
  position: absolute;
  z-index: 1;
  top: 6px;
  left: 2px;
}
.properties_page_google_reviews_author_data .properties_page_google_reviews_author_name {
  margin: 0 0 0.25em;
  text-transform: capitalize;
}
.properties_page_google_reviews_author_data .properties_page_google_reviews_time {
  font-style: italic;
  font-size: 0.8em;
  color: #888;
}
.properties_page_google_reviews_author_data .properties_page_google_reviews_text {
  margin: 0.5em 0 0;
}

/*# sourceMappingURL=properties.css.map */
