// Base button styles
.sp-eab-button-component {
    cursor: pointer;
    padding: 0;
    margin: 0;
    border: none;
    background-color: #fff;
    color: #2F2F2F;
    box-shadow: none;
    outline: none;
    width: 100%;
	text-align: center;
}