@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

//@mixin sc_team--xl() {
@media #{$media_xl} {
    /* Team */
	.sc_team_default .sc_team_item_info {
		padding:2.1429em;
	}
}

//@mixin sc_team--md() {
@media #{$media_md} {
    /* Team */
	.sc_team_item_thumb .sc_team_item_content {
		display:none;
	}
	.sc_team_default .sc_team_item_info {
		padding:1.6154em;
	}
}

//@mixin sc_team--sm() {
@media #{$media_sm} {
    /* Team */
	.team_member_page .team_member_featured {
		padding: 0 0 2em;
		width: 100%;
		float: none;
	}
}

//@mixin sc_team--xs() {
@media #{$media_xs} {
    /* Team */
	.sc_team_default .sc_team_item_info {
		padding:1.6154em;
	}
	.sc_team_default .sc_team_item_content {
		min-height:0;
		margin-top:1em;
	}
}