/* Widget: Custom links */
.widget_custom_links .custom_links_list {
  padding-left: 0;
  display: block !important;
  position: static;
  top: auto;
  left: auto;
  bottom: auto;
  right: auto;
  width: auto;
}

.widget_custom_links .custom_links_list_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  position: static;
  top: auto;
  left: auto;
  bottom: auto;
  right: auto;
  margin: 0 !important;
  padding: 0;
}

.widget_custom_links .custom_links_list_item + .custom_links_list_item {
  margin-top: 0.3em;
}

.widget_custom_links .custom_links_list_item:before {
  display: none;
}

.widget_custom_links .custom_links_list_item_link {
  position: relative !important;
  display: inline-block;
  vertical-align: top;
  padding: 0.3em;
}

.widget_custom_links span.custom_links_list_item_link {
  font-weight: bold;
}

.widget_custom_links .custom_links_list_item.with_icon .custom_links_list_item_link {
  padding-left: 1.5em;
}

.widget_custom_links .custom_links_list_item_image {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 0;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  width: 1.25em;
  height: auto;
  max-width: 100%;
}

.widget_custom_links .custom_links_list_item_icon {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 0;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  width: 1.5em;
  height: 1.5em;
  line-height: 1.5em;
}

.widget_custom_links .custom_links_list_item_icon.sc_icon_type_svg svg,
.widget_custom_links .custom_links_list_item_icon.sc_icon_type_svg object {
  width: 1em;
  height: 1em;
  line-height: 1em;
}

.widget_custom_links .custom_links_list_item_description {
  display: block;
  font-size: 0.75em;
  font-style: italic;
  line-height: 1.7em;
}

.widget_custom_links .custom_links_list_item_description + .custom_links_list_item_button {
  margin-top: 0.5em;
}

.widget_custom_links .custom_links_list_item_label {
  position: absolute;
  z-index: 1;
  top: -2em;
  right: -5em;
  font-size: 10px;
  line-height: 15px;
  font-weight: normal;
  background-color: #666;
  border-color: #666;
  color: #fff;
  display: inline-block;
  vertical-align: top;
  padding: 0.3em 1em;
  pointer-events: none;
}

.widget_custom_links .custom_links_list_item_label:before {
  content: " ";
  position: absolute;
  z-index: 1;
  top: 100%;
  left: 1em;
  width: 0;
  height: 0;
  border-style: solid;
  border-width: 4px 7px 0 0;
  border-top-color: inherit;
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-bottom-color: transparent !important;
}

.widget_custom_links .custom_links_list_item_label_hover .custom_links_list_item_label {
  opacity: 0;
  -webkit-transition: opacity 0.3s ease, transform 0.3s ease;
  -ms-transition: opacity 0.3s ease, transform 0.3s ease;
  transition: opacity 0.3s ease, transform 0.3s ease;
  -webkit-transform: translateY(3em);
  -ms-transform: translateY(3em);
  transform: translateY(3em);
}

.widget_custom_links .custom_links_list_item_label_hover:hover .custom_links_list_item_label {
  opacity: 1;
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
}

/*# sourceMappingURL=custom_links.css.map */
