$sp-primary-color: #1A74E4;

.sp-eab-inspector-control-top-section {
    padding: 0 18px 18px;

    .sp-eab-doc-link-button-wrapper {
        width: 100%;
        margin-top: -15px;
        margin-left: 35px;
    }

    .sp-eab-doc-link-button {
        color: $sp-primary-color;
        font-size: 12px;
        font-weight: 600;
        line-height: 16px;
        text-decoration: none;

        &:focus {
            outline: none;
            box-shadow: none;
        }
    }

    .sp-eab-inspector-control-button-list {
        width: 248px;
		margin-top: 12px;
    }

    .sp-eab-block-preview-button {
        color: #FFF;
        font-size: 12px;
        line-height: 14px;
        font-weight: 600;
        text-decoration: none;
        background: $sp-primary-color;
        transition: all 0.3s ease-in-out;
        cursor: pointer;
        border: none;
        border-radius: 4px;
        padding: 12px 16px;

        &:hover {
            background: $sp-primary-color;
        }

        &:focus {
            box-shadow: none;
            outline: none;
        }

        &.eab-ready-patterns {
            background-color: var(--eab-primary-color);
        }
    }
}

.sp-eab-block-preview-button {
	color: #FFF;
	font-size: 13px;
	line-height: 14px;
	font-weight: 600;
	text-decoration: none;
	background: $sp-primary-color;
	transition: all 0.4s ease-in-out;
	cursor: pointer;
	border: none;
	border-radius: 4px;
	padding: 15px 16px;

	&:hover {
		background: $sp-primary-color;
	}

	&:focus {
		box-shadow: none;
		outline: none;
	}

	&.eab-ready-patterns {
		background-color: var(--eab-primary-color);

		&:hover {
			background-color: #f4552a;
		}
	}

	&.eab-block-preview:hover {
		color: #fff;
		background-color: #1b63d2;
	}
}

div:has(>.sp-easy-accordion-tabs-panel)~div:has(>.block-editor-block-inspector__advanced) {
	display: none;
}