.sc_portfolio_masonry_wrap {
  position: relative;
  margin-right: -30px;
}

.sc_portfolio_masonry_wrap .sc_portfolio_masonry_item {
  position: relative;
  display: inline-block;
  vertical-align: top;
  padding: 0 30px 30px 0;
  margin-bottom: 0;
  width: 50%;
  border-width: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.sc_portfolio_masonry_wrap.no_margin {
  margin-right: 0;
}

.sc_portfolio_masonry_wrap.no_margin .sc_portfolio_masonry_item {
  padding: 0;
}

.sc_portfolio_masonry_wrap .sc_portfolio_masonry_item-1_3 {
  width: 33.3333%;
}

.sc_portfolio_masonry_wrap .sc_portfolio_masonry_item-1_4 {
  width: 25%;
}

.sc_portfolio_columns_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}

.sc_portfolio_slider .sc_portfolio_item,
.sc_portfolio_columns_wrap .sc_portfolio_item {
  display: inline-block;
  vertical-align: top;
  width: 100%;
  height: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.sc_portfolio_slider .sc_portfolio_item {
  margin-bottom: 0 !important;
}

.sc_portfolio {
  position: relative;
}

/* Style 'Default' */
.sc_portfolio_default .sc_portfolio_item_thumb {
  position: relative;
  overflow: hidden;
  margin-bottom: 0;
}
.sc_portfolio_default .sc_portfolio_item_thumb[class*="hover_"] {
  display: block !important;
}
.sc_portfolio_default .sc_portfolio_item_thumb img {
  width: 100%;
  height: auto;
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  width: 100%;
  overflow: hidden;
  text-align: center;
  display: block;
  margin: 0;
  opacity: 1;
  font-size: 1em;
  padding: 2em;
  -webkit-backface-visibility: hidden;
  -ms-backface-visibility: hidden;
  backface-visibility: hidden;
  -webkit-transition: none;
  -ms-transition: none;
  transition: none;
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_category {
  position: absolute;
  z-index: 1;
  top: 2em;
  left: 2em;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_category a {
  display: block;
  padding: 4px 1em;
  margin: 0 0.3em 0.3em 0;
  -webkit-border-radius: 2em;
  -ms-border-radius: 2em;
  border-radius: 2em;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_category a, .sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_category a .trx_addons_extended_taxonomy {
  -webkit-transition: background-color 0.3s ease, color 0.3s ease;
  -ms-transition: background-color 0.3s ease, color 0.3s ease;
  transition: background-color 0.3s ease, color 0.3s ease;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_title {
  font-weight: 400;
  font-size: 1.5em;
  line-height: 1.4em;
  margin: 0;
  text-transform: uppercase;
  text-align: left;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_title span {
  font-weight: 700;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_descr {
  margin: 0.5em 0 0;
  padding: 0;
  position: relative;
  text-align: left;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_descr .post_meta_item_title,
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_descr .post_meta_item_value {
  display: inline-block;
  vertical-align: top;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_descr .post_meta_item_title {
  padding-right: 0.5em;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_descr .post_meta_item_title:after {
  content: ':';
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_descr .post_meta_item_icon {
  display: inline-block;
  vertical-align: top;
  margin-right: 0.3em;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_category,
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_title,
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_descr {
  -webkit-transition: -webkit-transform 0.3s ease, color 0.3s ease, opacity 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease, color 0.3s ease, opacity 0.3s ease;
  transition: transform 0.3s ease, color 0.3s ease, opacity 0.3s ease;
}
.sc_portfolio_default .sc_portfolio_item_thumb .post_info .post_link {
  position: absolute;
  z-index: -1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_portfolio_default .sc_portfolio_item_thumb .mask {
  opacity: 0.5;
  background: -moz-linear-gradient(top, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0) 33%, rgba(0, 0, 0, 0.85) 100%);
  background: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0) 33%, rgba(0, 0, 0, 0.85) 100%);
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0) 33%, rgba(0, 0, 0, 0.85) 100%);
}
.sc_portfolio_default .sc_portfolio_item_thumb:hover .mask {
  opacity: 1;
}
.sc_portfolio_default .sc_portfolio_item_thumb:hover img {
  -webkit-transform: scale(1.1, 1.1);
  -ms-transform: scale(1.1, 1.1);
  transform: scale(1.1, 1.1);
}

/* Video in a portfolio archive */
.sc_portfolio_item .post_featured.post_video_play .mask {
  background: #000;
  opacity: 1;
}
.sc_portfolio_item .post_featured .trx_addons_video_player {
  max-width: 100%;
}

/* Video with autoplay and without thumb */
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb {
  height: 100%;
  min-height: 12rem;
}
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb > .post_video.with_video_autoplay {
  position: absolute;
  z-index: 3;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb > .post_video.with_video_autoplay iframe {
  height: 100% !important;
  background-color: #000;
}
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb > .post_video.with_video_autoplay .mejs-layers,
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb > .post_video.with_video_autoplay .mejs-controls {
  display: none;
}
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb > .post_video.with_video_autoplay video {
  object-fit: cover;
  height: 100% !important;
}
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb > .post_video.with_video_autoplay .trx_addons_video_player,
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb > .post_video.with_video_autoplay .video_frame,
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb > .post_video.with_video_autoplay .wp-video,
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb > .post_video.with_video_autoplay .mejs-container,
.sc_portfolio_columns_wrap .post_featured.with_video_autoplay.without_thumb > .post_video.with_video_autoplay .mejs-mediaelement {
  height: 100% !important;
}

.sc_portfolio .post_featured .mejs-mediaelement {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

/* GalleryFx */
.sc_portfolio_item * {
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.sc_portfolio_item .post_details {
  display: none;
}

.sc_portfolio_item_current {
  opacity: 0 !important;
}

.sc_portfolio_preview {
  position: fixed;
  z-index: 200000;
  top: 0;
  left: 0;
  width: 50%;
  height: 100%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-align-content: center;
  -ms-flex-line-pack: center;
  align-content: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  pointer-events: none;
  color: #fff;
}

.sc_portfolio_preview:before {
  content: ' ';
  opacity: 0;
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  width: 100%;
  height: 100%;
  -webkit-transition: opacity 0.6s ease;
  -ms-transition: opacity 0.6s ease;
  transition: opacity 0.6s ease;
  background-color: #000;
}

.sc_portfolio_preview_show {
  pointer-events: auto;
}

.sc_portfolio_preview_show:before {
  opacity: 1;
}

.sc_portfolio_preview_media_container {
  position: relative;
  z-index: 120;
  display: block;
  object-fit: contain;
  -webkit-transition: opacity 0.2s ease;
  -ms-transition: opacity 0.2s ease;
  transition: opacity 0.2s ease;
  -webkit-transform-origin: left top;
  -ms-transform-origin: left top;
  transform-origin: left top;
  -webkit-backface-visibility: hidden;
}

.sc_portfolio_preview_show .sc_portfolio_preview_media_container {
  -webkit-animation: sc-portfolio-show-media-container 0.3s forwards;
  -ms-animation: sc-portfolio-show-media-container 0.3s forwards;
  animation: sc-portfolio-show-media-container 0.3s forwards;
}

.sc_portfolio_preview_show .sc_portfolio_preview_image_animate {
  /* open */
  -webkit-transition: opacity 0.2s;
  -ms-transition: opacity 0.2s;
  transition: opacity 0.2s;
}

.sc_portfolio_preview_image_animate {
  /* close */
  -webkit-transition: -webkit-transform 0.3s, opacity 0.2s;
  -ms-transition: -ms-transform 0.3s, opacity 0.2s;
  transition: transform 0.3s, opacity 0.2s;
}

.sc_portfolio_preview_description {
  position: absolute;
  z-index: 140;
  top: 0;
  left: 100%;
  width: 100%;
  height: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-transition: -webkit-transform 1s, opacity 1s;
  -ms-transition: -ms-transform 1s, opacity 1s;
  transition: transform 1s, opacity 1s;
  -webkit-transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);
  -ms-transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);
  transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);
  -webkit-transform: translate3d(0, 30px, 0);
  -ms-transform: translate3d(0, 30px, 0);
  transform: translate3d(0, 30px, 0);
  padding: 0 3em;
  opacity: 0;
}

.sc_portfolio_preview_show .sc_portfolio_preview_description {
  opacity: 1;
  -webkit-transition-delay: 0.2s;
  -ms-transition-delay: 0.2s;
  transition-delay: 0.2s;
  -webkit-transform: translate3d(0, 0, 0);
  -ms-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0);
}

.sc_portfolio_preview_show .post_title {
  margin: 0 0 0.5em;
}

.sc_portfolio_preview_show .post_meta {
  font-size: 1em;
  line-height: 1.3em;
  margin-top: 0;
  margin-bottom: 2em;
}

.sc_portfolio_preview_show .post_description {
  font-size: 1.1429em;
  line-height: 2em;
}

.sc_portfolio_preview_show .post_description_content {
  max-width: 100%;
  margin-top: 1em;
}

.sc_portfolio_preview .sc_portfolio_preview_close {
  opacity: 0;
  position: fixed;
  z-index: 150;
  top: 0;
  right: 0;
  -webkit-transition: -webkit-transform 0.3s, opacity 0.3s;
  -ms-transition: -ms-transform 0.3s, opacity 0.3s;
  transition: transform 0.3s, opacity 0.3s;
  -webkit-transform: scale3d(0.6, 0.6, 1);
  -ms-transform: scale3d(0.6, 0.6, 1);
  transform: scale3d(0.6, 0.6, 1);
  width: 6rem;
  height: 6rem;
  line-height: 6rem;
  text-align: center;
}

.sc_portfolio_preview_image_loaded .sc_portfolio_preview_close {
  opacity: 1;
  -webkit-transform: scale3d(1, 1, 1);
  -ms-transform: scale3d(1, 1, 1);
  transform: scale3d(1, 1, 1);
}

/* Single post */
.portfolio_page {
  position: relative;
}

.portfolio_page_title:first-child {
  margin-top: 0;
}

.portfolio_page_subtitle {
  margin: 0 0 0.5em;
}

.portfolio_page_details_item {
  display: block;
}

.portfolio_page_details_item_title,
.portfolio_page_details_item_value {
  display: inline-block;
  vertical-align: top;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.portfolio_page_details_item_title {
  width: 27%;
  padding-right: 1em;
}

.portfolio_page_details_item_value {
  font-weight: 500;
  width: 73%;
}

.portfolio_page_details_item_icon {
  display: inline-block;
  vertical-align: top;
  margin-right: 0.5em;
}

.portfolio_page_details_share {
  margin-top: 1em;
  padding-top: 1em;
  border-top: 1px solid #ddd;
}

.portfolio_page_details_share .socials_wrap {
  margin-right: -10px;
}

.portfolio_page_details_share .socials_wrap .social_item {
  margin: 0 10px 8px 0;
}

.portfolio_page_details_share .socials_wrap .social_item .social_icon {
  background-color: transparent !important;
  color: #333;
  width: auto;
  height: auto;
  line-height: inherit;
  font-weight: normal;
  -webkit-transition: background-color 0.3s ease, color 0.3s ease;
  -ms-transition: background-color 0.3s ease, color 0.3s ease;
  transition: background-color 0.3s ease, color 0.3s ease;
}

.portfolio_page_details_button_link {
  margin-top: 1.5em;
}

.portfolio_page_details_wrap {
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.portfolio_page_details_top .portfolio_page_details_wrap {
  margin-bottom: 3em;
}

.portfolio_page_details_bottom .portfolio_page_details_wrap {
  margin-top: 3em;
}

.portfolio_page_details_top .portfolio_page_description,
.portfolio_page_details_bottom .portfolio_page_description {
  display: inline-block;
  vertical-align: top;
  width: 68%;
}

.portfolio_page_details_top .portfolio_page_details,
.portfolio_page_details_bottom .portfolio_page_details {
  display: inline-block;
  vertical-align: top;
  width: 32%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.portfolio_page_details_top .portfolio_page_description + .portfolio_page_details,
.portfolio_page_details_bottom .portfolio_page_description + .portfolio_page_details {
  padding-left: 2em;
}

.portfolio_page_details_left .portfolio_page_details_wrap {
  padding-right: 3em;
}

.portfolio_page_details_right .portfolio_page_details_wrap {
  padding-left: 3em;
}

.portfolio_page_details_left .portfolio_page_details_wrap,
.portfolio_page_details_right .portfolio_page_details_wrap {
  display: inline-block;
  vertical-align: top;
  width: 33%;
}

.portfolio_page_details_left .portfolio_page_content_wrap,
.portfolio_page_details_right .portfolio_page_content_wrap {
  display: inline-block;
  vertical-align: top;
  width: 67%;
}

.portfolio_page_gallery {
  margin-bottom: 3em;
}
.portfolio_page_gallery .portfolio_page_gallery_description {
  margin-top: 1.5em;
}
.portfolio_page_gallery figure {
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  margin-bottom: 0;
}

.portfolio_page_content .portfolio_page_gallery {
  margin: 0 0 1.5em;
}

.portfolio_page_content + .portfolio_page_gallery {
  margin-top: 3em;
  margin-bottom: 0;
}

[class*="portfolio_page_gallery_type_masonry_"] {
  position: relative;
  margin-right: -30px;
}

[class*="portfolio_page_gallery_type_masonry_"] .portfolio_page_gallery_item {
  position: relative;
  display: inline-block;
  vertical-align: top;
  padding: 0 30px 30px 0;
  margin-bottom: 0;
  border-width: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.portfolio_page_gallery_type_masonry_2 .portfolio_page_gallery_item {
  width: 50%;
}

.portfolio_page_gallery_type_masonry_3 .portfolio_page_gallery_item {
  width: 33.3333%;
}

.portfolio_page_gallery_type_masonry_4 .portfolio_page_gallery_item {
  width: 25%;
}

.portfolio_page_gallery_type_stream .portfolio_page_gallery_item + .portfolio_page_gallery_item {
  margin-top: 30px;
}

.portfolio_page_video {
  margin-bottom: 30px;
}
.portfolio_page_video .wp-video {
  width: unset !important;
}
.portfolio_page_video .portfolio_page_video_description {
  margin-top: 1.5em;
}

.portfolio_page_content .portfolio_page_video {
  margin: 0 0 1.5em;
}

.portfolio_page_content + .portfolio_page_video,
.portfolio_page_content + .portfolio_page_gallery + .portfolio_page_video {
  margin-top: 30px;
  margin-bottom: 0;
}

.portfolio_page_featured img {
  max-width: 100%;
  height: auto;
  vertical-align: top;
}

.portfolio_page_featured + .portfolio_page_title {
  margin: 1em 0 0;
}

.portfolio_page_title + .portfolio_page_meta {
  margin-top: 1em;
}

.portfolio_page_featured + .portfolio_page_content,
.portfolio_page_title + .portfolio_page_content,
.portfolio_page_meta + .portfolio_page_content {
  margin-top: 2em;
}

/*# sourceMappingURL=portfolio.css.map */
