/* Widget: Categories list*/
.widget_categories_list .categories_list_columns {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}

.widget_categories_list .categories_list_columns .categories_list_item {
  display: inline-block;
  vertical-align: top;
  width: 100%;
  height: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.widget_categories_list .categories_list_item {
  text-align: center;
  position: relative;
}

.widget_categories_list .categories_list_count {
  display: inline-block;
  margin-left: 0.5em;
}

.widget_categories_list .categories_list_link {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}

.widget_categories_list .sc_button_size_small .sc_button_icon {
  font-size: 1.4em;
}

.widget_categories_list .categories_list_style_1 .categories_list_title {
  margin: 0.5em 0 0;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}

.widget_categories_list .categories_list_style_1 .categories_list_item:hover .categories_list_title {
  color: #efa758;
}

.widget_categories_list .categories_list_style_1 .categories_list_image {
  vertical-align: top;
  height: 3em;
  line-height: 3em;
}

.widget_categories_list .categories_list_style_1 .categories_list_image img {
  display: inline-block;
  vertical-align: middle;
  width: auto;
  max-height: 3em;
}

.widget_categories_list .categories_list_style_1 .categories_list_icon {
  display: inline-block;
  vertical-align: middle;
  font-size: 3em;
  line-height: 1em;
  color: #efa758;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}

.widget_categories_list .categories_list_style_2 .categories_list_image img {
  width: 100%;
}

.widget_categories_list .categories_list_style_2 .categories_list_count {
  display: block;
  margin-left: 0;
}

.widget_categories_list .categories_list_style_2 .categories_list_image:after {
  content: ' ';
  display: block;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: rgba(0, 0, 0, 0.5);
  -webkit-transition: background-color 0.3s ease;
  -ms-transition: background-color 0.3s ease;
  transition: background-color 0.3s ease;
  pointer-events: none;
}

.widget_categories_list .categories_list_style_2 .categories_list_item:hover .categories_list_image:after {
  background-color: rgba(0, 0, 0, 0.1);
}

.widget_categories_list .categories_list_style_2 .categories_list_title {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 40%;
  font-weight: 300;
  margin: 0;
  padding: 1.5em 1em;
  background-color: rgba(255, 255, 255, 0.8);
  -webkit-box-shadow: 0px 0px 10px 0px rgba(0, 0, 0, 0.6);
  -ms-box-shadow: 0px 0px 10px 0px rgba(0, 0, 0, 0.6);
  box-shadow: 0px 0px 10px 0px rgba(0, 0, 0, 0.6);
}

.widget_categories_list .categories_list_style_2 .categories_list_item:hover .categories_list_title {
  color: #000000;
  background-color: #fff;
}

.widget_categories_list .categories_list_style_2 .categories_list_icon {
  display: inline-block;
  vertical-align: middle;
  width: 1.2em;
  height: 1.2em;
  line-height: 1.2em;
  text-align: center;
  margin-right: 0.3em;
}

.widget_categories_list .categories_list_style_3 .categories_list_item {
  overflow: hidden;
  background-color: #fafafa;
  position: relative;
}

.widget_categories_list .categories_list_style_3 .categories_list_info,
.widget_categories_list .categories_list_style_3 .categories_list_image {
  float: left;
  width: 50%;
  height: 14em;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
}

.widget_categories_list .categories_list_style_3 .categories_list_info {
  position: relative;
}

.widget_categories_list .categories_list_style_3 .categories_list_info .wrap_in {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 94%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  margin: 0;
  padding: 0;
}

.widget_categories_list .categories_list_style_3 .categories_list_count {
  display: block;
  margin-left: 0;
}

.widget_categories_list .categories_list_style_3 .categories_list_title {
  font-weight: 300;
  margin: 0.3em 0;
  text-transform: none;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}

.widget_categories_list .categories_list_style_3 .categories_list_item:hover .categories_list_title,
.widget_categories_list .categories_list_style_3 .categories_list_item:hover .categories_list_icon {
  color: #efa758;
}

.widget_categories_list .categories_list_style_3 .categories_list_icon {
  display: inline-block;
  vertical-align: middle;
  font-size: 2em;
  line-height: 1em;
  width: 1em;
  height: 1em;
  line-height: 1em;
  text-align: center;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}

.widget_categories_list .categories_list_style_3 img.categories_list_icon {
  max-height: 1em;
  width: auto;
}

/*# sourceMappingURL=categories_list.css.map */
