@media (max-width: 1023px) {
  /* Courses */
  .sc_courses_default .trx_addons_hover_content .trx_addons_hover_text,
  .sc_courses_default .trx_addons_hover_content .trx_addons_hover_links a {
    margin-top: 1.5em;
  }

  .sc_courses_default .trx_addons_hover_content .trx_addons_hover_links a {
    padding: 1em;
    font-size: 10px;
  }
}
@media (max-width: 767px) {
  /* Courses */
  .sc_courses_default .trx_addons_hover_content {
    padding: 10px;
  }

  .sc_courses_default .trx_addons_hover_content .trx_addons_hover_text,
  .sc_courses_default .trx_addons_hover_content .trx_addons_hover_links a {
    margin-top: 1.25em;
  }

  .sc_courses_default .trx_addons_hover_content .trx_addons_hover_links a + a {
    margin-left: 0.3em;
  }

  .sc_courses_default .sc_courses_item_price {
    font-size: 1.5em;
  }

  .courses_single .courses_page_header > .courses_page_price,
  .courses_single .courses_page_price + .courses_page_meta {
    font-size: 1.2em;
    line-height: 1.4em;
  }

  .courses_single .courses_page_header > .courses_page_price {
    float: none;
    margin-bottom: 0.5em;
    margin-left: 0;
  }

  .courses_single .courses_page_price + .courses_page_meta {
    margin-top: 0;
  }
}

/*# sourceMappingURL=courses.responsive.css.map */
