.sp-eab-media-control__wrapper {
	// .sp-eab-video-player {
	// 	height: 100%;
	// 	position: absolute;
	// 	overflow: hidden;
	// 	-webkit-transition: opacity 1s;
	// 	-o-transition: opacity 1s;
	// 	transition: opacity 1s;
	// 	top: 0;
	// 	left: 0;
	// 	z-index: 1;

	// 	video {
	// 		width: 100%;
	// 		height: 100%;
	// 		margin: 0;
	// 		object-fit: cover;
	// 		background-size: cover;
	// 	}
	// }
}