const fontAwesome = {
	Arrows: [
		"fa fa-angle-double-down",
		"fa fa-angle-double-left",
		"fa fa-angle-double-right",
		"fa fa-angle-double-up",
		"fa fa-times",
		"fa fa-angle-down",
		"fa fa-angle-left",
		"fa fa-angle-right",
		"fa fa-angle-up",
		"fa fa-window-close",
		"fa fa-arrow-circle-down",
		"fa fa-arrow-circle-left",
		"fa fa-arrow-circle-right",
		"fa fa-window-close-o",
		"fa fa-arrow-circle-up",
		"fa fa-arrow-down",
		"fa fa-arrow-left",
		"fa fa-arrow-right",
		"fa fa-arrow-up",
		"fa fa-times-circle",
		"fa fa-arrows",
		"fa fa-arrows-alt",
		"fa fa-arrows-h",
		"fa fa-arrows-v",
		"fa fa-caret-down",
		"fa fa-caret-left",
		"fa fa-caret-right",
		"fa fa-caret-up",
		"fa fa-chevron-circle-down",
		"fa fa-chevron-circle-left",
		"fa fa-chevron-circle-right",
		"fa fa-chevron-circle-up",
		"fa fa-chevron-down",
		"fa fa-chevron-left",
		"fa fa-chevron-right",
		"fa fa-chevron-up",
		"fa fa-hand-o-down",
		"fa fa-hand-o-left",
		"fa fa-hand-o-right",
		"fa fa-hand-o-up",
		"fa fa-long-arrow-down",
		"fa fa-long-arrow-left",
		"fa fa-long-arrow-right",
		"fa fa-long-arrow-up",
		"fa fa-arrow-circle-o-down",
		"fa fa-arrow-circle-o-left",
		"fa fa-arrow-circle-o-right",
		"fa fa-arrow-circle-o-up",
		"fa fa-caret-square-o-down",
		"fa fa-caret-square-o-left",
		"fa fa-caret-square-o-right",
		"fa fa-caret-square-o-up",
		"fa fa-exchange",
		"fa fa-toggle-down",
		"fa fa-toggle-left",
		"fa fa-toggle-right",
		"fa fa-toggle-up",
	],
	Social: [
		"fa fa-facebook",
		"fa fa-facebook-square",
		"fa fa-twitter",
		"fa fa-twitter-square",
		"fa fa-instagram",
		"fa fa-linkedin",
		"fa fa-github",
		"fa fa-wordpress",
		"fa fa-whatsapp",
		"fa fa-behance",
		"fa fa-google-plus",
		"fa fa-google-plus-square",
		"fa fa-pinterest",
	],
	Communication: [
		"fa fa-address-book",
		"fa fa-address-card",
		"fa fa-bell",
		"fa fa-bell-slash",
		"fa fa-bluetooth",
		"fa fa-bullhorn",
		"fa fa-comment",
		"fa fa-comment-o",
		"fa fa-comments",
		"fa fa-comments-o",
		"fa fa-envelope",
		"fa fa-envelope-o",
		"fa fa-envelope-square",
		"fa fa-fax",
		"fa fa-inbox",
		"fa fa-language",
		"fa fa-microphone",
		"fa fa-microphone-slash",
		"fa fa-mobile",
		"fa fa-paper-plane",
		"fa fa-paper-plane-o",
		"fa fa-phone",
		"fa fa-phone-square",
		"fa fa-rss",
		"fa fa-rss-square",
		"fa fa-tty",
		"fa fa-wifi",
	],
	Accessibility: [
		"fa fa-american-sign-language-interpreting",
		"fa fa-assistive-listening-systems",
		"fa fa-audio-description",
		"fa fa-blind",
		"fa fa-braille",
		"fa fa-deaf",
		"fa fa-low-vision",
		"fa fa-question-circle",
		"fa fa-sign-language",
		"fa fa-tty",
		"fa fa-universal-access",
		"fa fa-wheelchair",
	],
	"Audio & Video": [
		"fa fa-backward",
		"fa fa-circle",
		"fa fa-compress",
		"fa fa-eject",
		"fa fa-expand",
		"fa fa-fast-backward",
		"fa fa-fast-forward",
		"fa fa-file-audio-o",
		"fa fa-file-video-o",
		"fa fa-film",
		"fa fa-forward",
		"fa fa-headphones",
		"fa fa-microphone",
		"fa fa-microphone-slash",
		"fa fa-music",
		"fa fa-pause",
		"fa fa-pause-circle",
		"fa fa-play",
		"fa fa-play-circle",
		"fa fa-random",
		"fa fa-step-backward",
		"fa fa-step-forward",
		"fa fa-stop",
		"fa fa-stop-circle",
		"fa fa-video-camera",
		"fa fa-volume-down",
		"fa fa-volume-off",
		"fa fa-volume-up",
		"fa fa-youtube",
	],
	Business: [
		"fa fa-address-book",
		"fa fa-address-card",
		"fa fa-archive",
		"fa fa-balance-scale",
		"fa fa-birthday-cake",
		"fa fa-book",
		"fa fa-briefcase",
		"fa fa-building",
		"fa fa-bullhorn",
		"fa fa-bullseye",
		"fa fa-calculator",
		"fa fa-calendar",
		"fa fa-certificate",
		"fa fa-clipboard",
		"fa fa-coffee",
		"fa fa-columns",
		"fa fa-compass",
		"fa fa-copy",
		"fa fa-copyright",
		"fa fa-cut",
		"fa fa-edit",
		"fa fa-envelope",
		"fa fa-envelope-open",
		"fa fa-envelope-square",
		"fa fa-eraser",
		"fa fa-fax",
		"fa fa-file",
		"fa fa-file-text",
		"fa fa-folder",
		"fa fa-folder-open",
		"fa fa-globe",
		"fa fa-industry",
		"fa fa-paperclip",
		"fa fa-paste",
		"fa fa-pencil-square",
		"fa fa-percent",
		"fa fa-phone",
		"fa fa-phone-square",
		"fa fa-registered",
		"fa fa-save",
		"fa fa-sitemap",
		"fa fa-sticky-note",
		"fa fa-suitcase",
		"fa fa-table",
		"fa fa-tag",
		"fa fa-tags",
		"fa fa-tasks",
		"fa fa-thumb-tack",
		"fa fa-trademark",
	],
	Code: [
		"fa fa-archive",
		"fa fa-barcode",
		"fa fa-bug",
		"fa fa-code",
		"fa fa-code-fork",
		"fa fa-coffee",
		"fa fa-file",
		"fa fa-file-text",
		"fa fa-filter",
		"fa fa-fire-extinguisher",
		"fa fa-folder",
		"fa fa-folder-open",
		"fa fa-microchip",
		"fa fa-qrcode",
		"fa fa-shield",
		"fa fa-sitemap",
		"fa fa-terminal",
		"fa fa-user-secret",
		"fa fa-window-close",
		"fa fa-window-maximize",
		"fa fa-window-minimize",
		"fa fa-window-restore",
	],
	Computers: [
		"fa fa-desktop",
		"fa fa-download",
		"fa fa-hdd-o",
		"fa fa-headphones",
		"fa fa-laptop",
		"fa fa-microchip",
		"fa fa-mobile",
		"fa fa-plug",
		"fa fa-power-off",
		"fa fa-print",
		"fa fa-save",
		"fa fa-server",
		"fa fa-tablet",
		"fa fa-tv",
		"fa fa-upload",
	],
	Currency: [
		"fa fa-bitcoin",
		"fa fa-btc",
		"fa fa-dollar",
		"fa fa-eur",
		"fa fa-gbp",
		"fa fa-gg",
		"fa fa-ils",
		"fa fa-inr",
		"fa fa-jpy",
		"fa fa-krw",
		"fa fa-money",
		"fa fa-rub",
		"fa fa-try",
		"fa fa-usd",
	],
	"Date & Time": [
		"fa fa-bell",
		"fa fa-bell-slash",
		"fa fa-calendar",
		"fa fa-clock-o",
		"fa fa-hourglass",
		"fa fa-hourglass-end",
		"fa fa-hourglass-half",
		"fa fa-hourglass-start",
	],
	Design: [
		"fa fa-adjust",
		"fa fa-clone",
		"fa fa-copy",
		"fa fa-crop",
		"fa fa-crosshairs",
		"fa fa-cut",
		"fa fa-edit",
		"fa fa-eraser",
		"fa fa-eye",
		"fa fa-eye-slash",
		"fa fa-object-group",
		"fa fa-object-ungroup",
		"fa fa-paint-brush",
		"fa fa-paste",
		"fa fa-pencil",
		"fa fa-save",
		"fa fa-tint",
	],
	Editors: [
		"fa fa-align-center",
		"fa fa-align-justify",
		"fa fa-align-left",
		"fa fa-align-right",
		"fa fa-bold",
		"fa fa-clipboard",
		"fa fa-columns",
		"fa fa-copy",
		"fa fa-cut",
		"fa fa-edit",
		"fa fa-eraser",
		"fa fa-file",
		"fa fa-file-text",
		"fa fa-font",
		"fa fa-header",
		"fa fa-indent",
		"fa fa-italic",
		"fa fa-link",
		"fa fa-list",
		"fa fa-list-alt",
		"fa fa-list-ol",
		"fa fa-list-ul",
		"fa fa-outdent",
		"fa fa-paperclip",
		"fa fa-paragraph",
		"fa fa-paste",
		"fa fa-pencil",
		"fa fa-print",
		"fa fa-quote-left",
		"fa fa-quote-right",
		"fa fa-reply",
		"fa fa-reply-all",
		"fa fa-share",
		"fa fa-strikethrough",
		"fa fa-subscript",
		"fa fa-superscript",
		"fa fa-table",
		"fa fa-tasks",
		"fa fa-text-height",
		"fa fa-text-width",
		"fa fa-th",
		"fa fa-th-large",
		"fa fa-th-list",
		"fa fa-trash",
		"fa fa-underline",
		"fa fa-undo",
	],
	Files: [
		"fa fa-archive",
		"fa fa-clone",
		"fa fa-copy",
		"fa fa-cut",
		"fa fa-file",
		"fa fa-file-text",
		"fa fa-file-archive-o",
		"fa fa-file-audio-o",
		"fa fa-file-code-o",
		"fa fa-file-excel-o",
		"fa fa-file-image-o",
		"fa fa-file-pdf-o",
		"fa fa-file-powerpoint-o",
		"fa fa-file-video-o",
		"fa fa-file-word-o",
		"fa fa-folder",
		"fa fa-folder-open",
		"fa fa-paste",
		"fa fa-save",
		"fa fa-sticky-note",
	],
	Genders: [
		"fa fa-genderless",
		"fa fa-mars",
		"fa fa-mars-double",
		"fa fa-mars-stroke",
		"fa fa-mars-stroke-h",
		"fa fa-mars-stroke-v",
		"fa fa-mercury",
		"fa fa-neuter",
		"fa fa-transgender",
		"fa fa-transgender-alt",
		"fa fa-venus",
		"fa fa-venus-double",
		"fa fa-venus-mars",
	],
	Hands: [
		"fa fa-hand-lizard-o",
		"fa fa-hand-rock-o",
		"fa fa-hand-pointer-o",
		"fa fa-hand-paper-o",
		"fa fa-hand-o-right",
		"fa fa-hand-o-left",
		"fa fa-hand-o-up",
		"fa fa-hand-o-down",
		"fa fa-thumbs-down",
		"fa fa-thumbs-up",
		"fa fa-hand-scissors-o",
		"fa fa-hand-spock-o",
		"fa fa-thumbs-o-up",
		"fa fa-thumbs-o-down",
	],
	Health: [
		"fa fa-ambulance",
		"fa fa-h-square",
		"fa fa-heart",
		"fa fa-heartbeat",
		"fa fa-medkit",
		"fa fa-hospital-o",
		"fa fa-plus-square",
		"fa fa-stethoscope",
		"fa fa-user-md",
		"fa fa-wheelchair",
	],
	Images: [
		"fa fa-adjust",
		"fa fa-bolt",
		"fa fa-camera",
		"fa fa-camera-retro",
		"fa fa-clone",
		"fa fa-compress",
		"fa fa-expand",
		"fa fa-eye",
		"fa fa-eye-slash",
		"fa fa-file-image-o",
		"fa fa-film",
		"fa fa-id-badge",
		"fa fa-id-card",
		"fa fa-image",
		"fa fa-sliders",
		"fa fa-tint",
	],
	Interfaces: [
		"fa fa-ban",
		"fa fa-barcode",
		"fa fa-bars",
		"fa fa-beer",
		"fa fa-bell",
		"fa fa-bell-slash",
		"fa fa-bug",
		"fa fa-bullhorn",
		"fa fa-bullseye",
		"fa fa-calculator",
		"fa fa-calendar",
		"fa fa-certificate",
		"fa fa-check",
		"fa fa-check-circle",
		"fa fa-check-square",
		"fa fa-circle",
		"fa fa-clipboard",
		"fa fa-clone",
		"fa fa-cloud",
		"fa fa-cloud-download",
		"fa fa-cloud-upload",
		"fa fa-coffee",
		"fa fa-cog",
		"fa fa-cogs",
		"fa fa-copy",
		"fa fa-cut",
		"fa fa-database",
		"fa fa-download",
		"fa fa-edit",
		"fa fa-ellipsis-h",
		"fa fa-ellipsis-v",
		"fa fa-envelope",
		"fa fa-envelope-open",
		"fa fa-eraser",
		"fa fa-exclamation",
		"fa fa-exclamation-circle",
		"fa fa-exclamation-triangle",
		"fa fa-external-link",
		"fa fa-external-link-square",
		"fa fa-eye",
		"fa fa-eye-slash",
		"fa fa-file",
		"fa fa-filter",
		"fa fa-flag",
		"fa fa-flag-checkered",
		"fa fa-folder",
		"fa fa-folder-open",
		"fa fa-hashtag",
		"fa fa-heart",
		"fa fa-history",
		"fa fa-home",
		"fa fa-i-cursor",
		"fa fa-info",
		"fa fa-info-circle",
		"fa fa-language",
		"fa fa-magic",
		"fa fa-microphone",
		"fa fa-microphone-slash",
		"fa fa-minus",
		"fa fa-minus-circle",
		"fa fa-minus-square",
		"fa fa-paste",
		"fa fa-pencil",
		"fa fa-plus",
		"fa fa-plus-circle",
		"fa fa-plus-square",
		"fa fa-qrcode",
		"fa fa-question",
		"fa fa-question-circle",
	],
	Maps: ["fa fa-location-arrow", "fa fa-map", "fa fa-map-marker", "fa fa-map-pin", "fa fa-map-signs", "fa fa-road"],
	"Payments & Shopping": [
		"fa fa-cart-arrow-down",
		"fa fa-cart-plus",
		"fa fa-cc-amex",
		"fa fa-cc-diners-club",
		"fa fa-cc-discover",
		"fa fa-cc-jcb",
		"fa fa-cc-mastercard",
		"fa fa-cc-paypal",
		"fa fa-cc-stripe",
		"fa fa-cc-visa",
		"fa fa-certificate",
		"fa fa-credit-card",
		"fa fa-gift",
		"fa fa-google-wallet",
		"fa fa-paypal",
		"fa fa-shopping-bag",
		"fa fa-shopping-cart",
	],
	Spinners: [
		"fa fa-asterisk",
		"fa fa-certificate",
		"fa fa-cog",
		"fa fa-compass",
		"fa fa-crosshairs",
		"fa fa-life-ring",
		"fa fa-spinner",
	],
	Status: [
		"fa fa-ban",
		"fa fa-battery-empty",
		"fa fa-battery-full",
		"fa fa-battery-half",
		"fa fa-battery-quarter",
		"fa fa-battery-three-quarters",
		"fa fa-bell",
		"fa fa-bell-slash",
		"fa fa-calendar",
		"fa fa-calendar-check-o",
		"fa fa-calendar-minus-o",
		"fa fa-calendar-plus-o",
		"fa fa-calendar-times-o",
		"fa fa-cart-arrow-down",
		"fa fa-cart-plus",
		"fa fa-exclamation",
		"fa fa-exclamation-circle",
		"fa fa-exclamation-triangle",
		"fa fa-eye",
		"fa fa-eye-slash",
		"fa fa-file",
		"fa fa-file-o",
		"fa fa-folder",
		"fa fa-folder-open",
		"fa fa-info",
		"fa fa-info-circle",
		"fa fa-lock",
		"fa fa-minus",
		"fa fa-minus-circle",
		"fa fa-minus-square",
		"fa fa-plus",
		"fa fa-plus-circle",
		"fa fa-plus-square",
		"fa fa-question",
		"fa fa-question-circle",
		"fa fa-shield",
		"fa fa-shopping-cart",
		"fa fa-sign-in",
		"fa fa-sign-out",
		"fa fa-thermometer-empty",
		"fa fa-thermometer-full",
		"fa fa-thermometer-half",
		"fa fa-thermometer-quarter",
		"fa fa-thermometer-three-quarters",
		"fa fa-thumbs-down",
		"fa fa-thumbs-up",
		"fa fa-toggle-off",
		"fa fa-toggle-on",
		"fa fa-unlock",
		"fa fa-unlock-alt",
	],
	"Users & People": [
		"fa fa-address-book",
		"fa fa-address-card",
		"fa fa-bed",
		"fa fa-blind",
		"fa fa-child",
		"fa fa-female",
		"fa fa-frown-o",
		"fa fa-id-badge",
		"fa fa-id-card",
		"fa fa-male",
		"fa fa-meh-o",
		"fa fa-power-off",
		"fa fa-smile-o",
		"fa fa-street-view",
		"fa fa-user",
		"fa fa-user-circle",
		"fa fa-user-md",
		"fa fa-user-plus",
		"fa fa-user-secret",
		"fa fa-user-times",
		"fa fa-users",
		"fa fa-wheelchair",
	],
	Vehicles: [
		"fa fa-ambulance",
		"fa fa-bicycle",
		"fa fa-bus",
		"fa fa-car",
		"fa fa-fighter-jet",
		"fa fa-motorcycle",
		"fa fa-paper-plane",
		"fa fa-plane",
		"fa fa-rocket",
		"fa fa-ship",
		"fa fa-shopping-cart",
		"fa fa-space-shuttle",
		"fa fa-subway",
		"fa fa-taxi",
		"fa fa-train",
		"fa fa-truck",
		"fa fa-wheelchair",
	],
	Writing: [
		"fa fa-archive",
		"fa fa-book",
		"fa fa-bookmark",
		"fa fa-edit",
		"fa fa-envelope",
		"fa fa-envelope-open",
		"fa fa-eraser",
		"fa fa-file",
		"fa fa-file-o",
		"fa fa-folder",
		"fa fa-folder-open",
		"fa fa-keyboard-o",
		"fa fa-newspaper-o",
		"fa fa-paper-plane",
		"fa fa-paperclip",
		"fa fa-paragraph",
		"fa fa-pencil",
		"fa fa-quote-left",
		"fa fa-quote-right",
		"fa fa-sticky-note",
	],
};

export default fontAwesome;
