.sp-eab-text-area-control {
    .components-base-control .components-base-control__field {
        .components-base-control__label {
            font-size: 13px;
            font-weight: 400;
            line-height: 20px;
            text-transform: capitalize;
        }

        .components-textarea-control__input {
            height: 60px;
        }

    }

}