.sp-eab-media-control__wrapper {
    height: 130px;
    border-radius: 3px;
    border: 1px solid #e6e7e9;
    position: relative;
    background-color: #fff;
    background-position: center !important;
    background-repeat: no-repeat !important;
    background-size: cover !important;
    -webkit-display: flex;
    -moz-display: flex;
    -ms-display: flex;
    display: flex;
    flex-direction: column;
    justify-content: flex-end;

    .sp-eab-media-video {
        position: absolute;
        top: 42%;
        left: 50%;
        transform: translate(-50%, -50%);
        font-size: 45px;
        color: #2f8db4;
    }
}

.sp-eab-media-control__clickable {
    cursor: pointer;
    border: unset;
    color: transparent;
    background-color: transparent;
}

.sp-eab-media-control__button {
    width: 30px;
    height: 30px;
    -webkit-display: flex;
    -moz-display: flex;
    -ms-display: flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    justify-content: center;
    border-radius: 50%;
}

.sp-eab-media-control__button--add {
    background-color: #ccc;
}

.sp-eab-media-control__clickable--add {
    width: 100%;
    height: 100%;
    -webkit-display: flex;
    -moz-display: flex;
    -ms-display: flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    justify-content: center;
}

.sp-eab-media-control__clickable--replace {
    width: 100%;
    height: 25px;
    color: #50575e;
    background-color: #f0f0f1;
    position: absolute;
    bottom: -1px;
    -webkit-display: flex;
    -moz-display: flex;
    -ms-display: flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    justify-content: center;
    z-index: 1;
}

.sp-eab-media-control__button--close {
    background-color: #f0f0f1;
    position: absolute;
    top: 0;
    right: 0;
    z-index: 1;
}

.sp-eab-media-control__clickable--add span,
.sp-eab-media-control__clickable--close span {
    color: #50575e;
    font-size: 22px;
    font-weight: 700;
    margin-top: -3px;
}

.sp-eab-infobox .sp-eab-infobox-num,
.sp-eab-infobox .sp-eab-infobox-icon {
    line-height: 0;
}

.sp-eab-infobox .sp-eab-infobox-image {
    flex-shrink: 0;
}

.sp-eab-image-picker {
    background-position: center !important;
    background-repeat: no-repeat !important;
    background-size: cover !important;

    .sp-eab-popover-toggle-button {
        position: absolute;
        top: 50%;
        left: 50%;
        right: 0;
        bottom: 0;
        transform: translate(-50%, -50%);
        width: fit-content;
        height: 30px;

        &.active {
            outline: none !important;
        }
    }
}

.sp-easy-accordion-tabs-panel {
    .components-focal-point-picker__icon_container {
        background: var(--eab-primary-color);
        border: 6px solid #fff;
    }

}