/* Make VC row relative to enable using absolute position in columns */
.vc_row {
  position: relative;
}

.sc_column_fixed_placeholder {
  min-height: 1px;
}

/* Height variants for the empty space */
.vc_empty_space.sc_height_tiny {
  height: var(--sc-space-tiny) !important;
}

.vc_empty_space.sc_height_small {
  height: var(--sc-space-small) !important;
}

.vc_empty_space.sc_height_medium {
  height: var(--sc-space-medium) !important;
}

.vc_empty_space.sc_height_large,
.vc_empty_space.sc_height_big {
  height: var(--sc-space-large) !important;
}

.vc_empty_space.sc_height_huge {
  height: var(--sc-space-huge) !important;
}

/* Extra bg for VC columns and [trx_sc_content] */
.wpb_row[class*="sc_extra_bg_"],
.wpb_row[class*="sc_bg_mask_"],
.wpb_column[class*="sc_extra_bg_"] > .vc_column-inner,
.wpb_column[class*="sc_bg_mask_"] > .vc_column-inner,
.wpb_text_column[class*="sc_extra_bg_"],
.wpb_text_column[class*="sc_bg_mask_"],
.sc_content[class*="sc_extra_bg_"],
.sc_content[class*="sc_bg_mask_"] {
  position: relative;
  z-index: 0;
}

.wpb_text_column[class*="sc_bg_mask_"] > .wpb_wrapper {
  position: relative;
  z-index: 2;
}

.wpb_row[class*="sc_extra_bg_"]:after,
.wpb_column[class*="sc_extra_bg_"] > .vc_column-inner:after,
.wpb_text_column[class*="sc_extra_bg_"]:after,
.sc_content[class*="sc_extra_bg_"]:after {
  content: ' ';
  display: block;
  position: absolute;
  z-index: -1;
  background: inherit;
}

.wpb_row[class*="sc_bg_mask_"]:before,
.wpb_column[class*="sc_bg_mask_"] > .vc_column-inner:before,
.wpb_text_column[class*="sc_bg_mask_"]:before,
.sc_content[class*="sc_bg_mask_"]:before {
  content: ' ';
  display: block !important;
  background-color: inherit;
  position: absolute;
  z-index: 0;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}

.wpb_row.vc_parallax[class*="sc_bg_mask_"]:before {
  z-index: 1;
}

.wpb_row.sc_extra_bg_tiny[class*="sc_bg_mask_"]:before,
.wpb_row.sc_extra_bg_tiny:after,
.wpb_column.sc_extra_bg_tiny[class*="sc_bg_mask_"] > .vc_column-inner:before,
.wpb_column.sc_extra_bg_tiny > .vc_column-inner:after,
.wpb_text_column.sc_extra_bg_tiny[class*="sc_bg_mask_"]:before,
.wpb_text_column.sc_extra_bg_tiny:after,
.sc_content.sc_extra_bg_tiny[class*="sc_bg_mask_"]:before,
.sc_content.sc_extra_bg_tiny:after {
  position: absolute;
  top: -2em;
  right: -2em;
  bottom: -2em;
  left: -2em;
}

.wpb_row.sc_extra_bg_small[class*="sc_bg_mask_"]:before,
.wpb_row.sc_extra_bg_small:after,
.wpb_column.sc_extra_bg_small[class*="sc_bg_mask_"] > .vc_column-inner:before,
.wpb_column.sc_extra_bg_small > .vc_column-inner:after,
.wpb_text_column.sc_extra_bg_small[class*="sc_bg_mask_"]:before,
.wpb_text_column.sc_extra_bg_small:after,
.sc_content.sc_extra_bg_small[class*="sc_bg_mask_"]:before,
.sc_content.sc_extra_bg_small:after {
  position: absolute;
  top: -4em;
  right: -4em;
  bottom: -4em;
  left: -4em;
}

.wpb_row.sc_extra_bg_medium[class*="sc_bg_mask_"]:before,
.wpb_row.sc_extra_bg_medium:after,
.wpb_column.sc_extra_bg_medium[class*="sc_bg_mask_"] > .vc_column-inner:before,
.wpb_column.sc_extra_bg_medium > .vc_column-inner:after,
.wpb_text_column.sc_extra_bg_medium[class*="sc_bg_mask_"]:before,
.wpb_text_column.sc_extra_bg_medium:after,
.sc_content.sc_extra_bg_medium[class*="sc_bg_mask_"]:before,
.sc_content.sc_extra_bg_medium:after {
  position: absolute;
  top: -6em;
  right: -6em;
  bottom: -6em;
  left: -6em;
}

.wpb_row.sc_extra_bg_large[class*="sc_bg_mask_"]:before,
.wpb_row.sc_extra_bg_large:after,
.wpb_column.sc_extra_bg_large[class*="sc_bg_mask_"] > .vc_column-inner:before,
.wpb_column.sc_extra_bg_large > .vc_column-inner:after,
.wpb_text_column.sc_extra_bg_large[class*="sc_bg_mask_"]:before,
.wpb_text_column.sc_extra_bg_large:after,
.sc_content.sc_extra_bg_large[class*="sc_bg_mask_"]:before,
.sc_content.sc_extra_bg_large:after {
  position: absolute;
  top: -8em;
  right: -8em;
  bottom: -8em;
  left: -8em;
}

.wpb_row.sc_bg_mask_bg_color:before,
.wpb_column.sc_bg_mask_bg_color > .vc_column-inner:before,
.wpb_text_column.sc_bg_mask_bg_color:before,
.sc_content.sc_bg_mask_bg_color:before {
  background-color: inherit;
}

.wpb_row.sc_bg_mask_1:before,
.wpb_column.sc_bg_mask_1 > .vc_column-inner:before,
.wpb_text_column.sc_bg_mask_1:before,
.sc_content.sc_bg_mask_1:before {
  opacity: 0.1;
}

.wpb_row.sc_bg_mask_2:before,
.wpb_column.sc_bg_mask_2 > .vc_column-inner:before,
.wpb_text_column.sc_bg_mask_2:before,
.sc_content.sc_bg_mask_2:before {
  opacity: 0.2;
}

.wpb_row.sc_bg_mask_3:before,
.wpb_column.sc_bg_mask_3 > .vc_column-inner:before,
.wpb_text_column.sc_bg_mask_3:before,
.sc_content.sc_bg_mask_3:before {
  opacity: 0.3;
}

.wpb_row.sc_bg_mask_4:before,
.wpb_column.sc_bg_mask_4 > .vc_column-inner:before,
.wpb_text_column.sc_bg_mask_4:before,
.sc_content.sc_bg_mask_4:before {
  opacity: 0.4;
}

.wpb_row.sc_bg_mask_5:before,
.wpb_column.sc_bg_mask_5 > .vc_column-inner:before,
.wpb_text_column.sc_bg_mask_5:before,
.sc_content.sc_bg_mask_5:before {
  opacity: 0.5;
}

.wpb_row.sc_bg_mask_6:before,
.wpb_column.sc_bg_mask_6 > .vc_column-inner:before,
.wpb_text_column.sc_bg_mask_6:before,
.sc_content.sc_bg_mask_6:before {
  opacity: 0.6;
}

.wpb_row.sc_bg_mask_7:before,
.wpb_column.sc_bg_mask_7 > .vc_column-inner:before,
.wpb_text_column.sc_bg_mask_7:before,
.sc_content.sc_bg_mask_7:before {
  opacity: 0.7;
}

.wpb_row.sc_bg_mask_8:before,
.wpb_column.sc_bg_mask_8 > .vc_column-inner:before,
.wpb_text_column.sc_bg_mask_8:before,
.sc_content.sc_bg_mask_8:before {
  opacity: 0.8;
}

.wpb_row.sc_bg_mask_9:before,
.wpb_column.sc_bg_mask_9 > .vc_column-inner:before,
.wpb_text_column.sc_bg_mask_9:before,
.sc_content.sc_bg_mask_9:before {
  opacity: 0.9;
}

/* Move container controls to the right side */
.compose-mode .vc_controls-container > div.vc_controls-out-tl {
  left: auto;
  right: 0;
}

/* Hide 'Add' button on the some shortcodes */
.compose-mode .sc_widget_slider.vc_empty-element:after {
  display: none !important;
}

/* Put layouts item in the same line */
.compose-mode .vc_element.sc_layouts_item {
  display: inline-block;
}

/* Fix controls height */
.compose-mode .vc_element-name .vc_btn-content {
  height: unset;
}

/* Shape dividers */
.vc_shape_divider {
  overflow: hidden;
  position: absolute;
  left: 0;
  width: 100%;
  line-height: 0;
  direction: ltr;
  pointer-events: none;
}

.vc_shape_divider svg {
  display: block;
  width: 100%;
}

.vc_shape_divider_top {
  top: -0.3px;
}

.vc_shape_divider_bottom {
  bottom: -0.3px;
  -webkit-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}

.shape_divider_top_front .vc_shape_divider,
.shape_divider_top_bottom .vc_shape_divider {
  z-index: 9;
}

/* Decorate Flexslider */
.flex-direction-nav li {
  position: static;
}

.flex-control-nav li:before {
  display: none;
}

/* Progress bar - style 'Narrow' */
.vc_progress_bar.vc_progress_bar_narrow .vc_single_bar {
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  height: 4px;
  margin-top: 1.4em;
}

.vc_progress_bar.vc_progress_bar_narrow .vc_single_bar .vc_bar {
  height: 4px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.vc_progress_bar.vc_progress_bar_narrow .vc_single_bar + .vc_single_bar {
  margin-top: 3.3em;
}

.vc_progress_bar.vc_progress_bar_narrow .vc_single_bar .vc_label {
  display: block;
  width: 100%;
  position: absolute;
  z-index: 1;
  top: -1.625em;
  left: 0;
  font-size: 1.0667em;
  line-height: 1.5em;
  font-weight: 400;
  font-style: normal;
  padding: 0;
  text-shadow: none;
}

.vc_progress_bar.vc_progress_bar_narrow .vc_single_bar .vc_label .vc_label_units {
  position: absolute;
  z-index: 1;
  top: 1px;
  right: 0;
  font-size: 0.875em;
  font-style: italic;
}

/* Message Box - add close button */
.vc_message_box_closeable {
  position: relative;
}

.vc_message_box_closeable:after {
  content: '\e8be';
  font-family: "trx_addons_icons";
  font-size: 1.5em;
  line-height: 1em;
  font-weight: 400;
  padding: 1em;
  color: inherit;
  cursor: pointer;
  position: absolute;
  z-index: 1;
  top: 50%;
  right: 0;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
}

/* Remove margins from first and last elements on the page */
.vc_row:first-child h1:first-child,
.vc_row:first-child h2:first-child,
.vc_row:first-child h3:first-child,
.vc_row:first-child h4:first-child,
.vc_row:first-child h5:first-child,
.vc_row:first-child h6:first-child {
  margin-top: 0;
}

.vc_row:last-child h1:last-child,
.vc_row:last-child h2:last-child,
.vc_row:last-child h3:last-child,
.vc_row:last-child h4:last-child,
.vc_row:last-child h5:last-child,
.vc_row:last-child h6:last-child {
  margin-bottom: 0;
}

/* Device-specific responsive must be inside main CSS, not in responsive
-------------------------------------------------------------------------- */
@media (min-width: 1680px) and (max-width: 2159px) {
  /* WPBakery PageBuilder */
  .wpb_row.hide_bg_image_on_desktop,
  .wpb_column.hide_bg_image_on_desktop .vc_column-inner {
    background-image: none !important;
  }

  .wpb_row.hide_bg_image_on_desktop[class*="sc_bg_mask_"]:before,
  .wpb_column.hide_bg_image_on_desktop[class*="sc_bg_mask_"] > .vc_column-inner:before {
    display: none !important;
  }
}

/*# sourceMappingURL=js_composer.css.map */
