@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

//@mixin sc_blogger--xl() {
@media #{$media_xl} {
	/* Blogger */

	/* Layout: Cards */
	.sc_blogger_cards_content {
		&:after {
			bottom: 1.5em;
		}
	}
}	

//@mixin sc_blogger--lg() {
@media #{$media_lg} {
	/* Blogger */
	
	/* Layout: Magazine */
	.sc_blogger_news_magazine {
		.sc_blogger_grid_wrap.sc_blogger_grid_columns_3 .sc_blogger_item:nth-child(n+2) .sc_blogger_item_title + .sc_blogger_item_meta {
			display: none;
		}
	}

	/* Layout: Cards */
	.sc_blogger_cards {
		@include flex-direction(column);
		@include flex-justify-content(flex-start);
		@include flex-align-items(flex-start);
		@include flex-wrap(wrap);
	}
	.sc_blogger_cards_header {
		@include flex-justify-content(flex-start);
		@include flex-align-items(center);
		width: 100%;
		margin: 0 0 1em 0;
	}
	.sc_blogger_cards_content {
		.sc_blogger_cards_header + & {
			width: 100%;
		}
		&:after {
			display: none;
		}
		.sc_blogger_content {
			padding: 0 0 1em 0;
		}
		.sc_blogger_item {
			@include box-shadow(none);
		}
		.sc_blogger_item:not(:first-child) {
			margin-left: 1em;
			@include box-shadow(none);
		}
	}
}

//@mixin sc_blogger--md() {
@media #{$media_md} {
	/* Blogger */
	
	/* Layout: Magazine */
	.sc_blogger_news_magazine {
		.sc_blogger_grid_wrap.sc_blogger_grid_columns_2 .sc_blogger_item:first-child,
		.sc_blogger_grid_wrap.sc_blogger_grid_columns_3 .sc_blogger_item:first-child {
			width: 50.5%;
		}
		.sc_blogger_grid_wrap.sc_blogger_grid_columns_2 .sc_blogger_item:nth-child(n+2),
		.sc_blogger_grid_wrap.sc_blogger_grid_columns_3 .sc_blogger_item:nth-child(n+2) {
			width: 46%;
			margin-right: 0 !important;
		}
		.sc_blogger_grid_wrap.sc_blogger_grid_columns_3 .sc_blogger_item:last-child {
			padding-bottom: 0;
			margin-bottom: 0;
			border-bottom: none;
		}
	}

	/* Layout: Panel */
	.sc_blogger_panel {
		.sc_blogger_item {
			.sc_blogger_item_title,
			.sc_blogger_item_meta,
			.sc_blogger_item_excerpt,
			.sc_blogger_item_button,
			&:hover .sc_blogger_item_title,
			&:hover .sc_blogger_item_meta,
			&:hover .sc_blogger_item_excerpt,
			&:hover .sc_blogger_item_button {
				@include translateY(0);
				opacity: 1;
			}
		}
	}
}

//@mixin sc_blogger--sm() {
@media #{$media_sm} {
	/* Blogger */
	
	/* Default */
	.sc_blogger_item_default.sc_blogger_item_image_position_left .sc_blogger_item_body,
	.sc_blogger_item_default.sc_blogger_item_image_position_right .sc_blogger_item_body,
	.sc_blogger_item_default.sc_blogger_item_image_position_alter .sc_blogger_item_body {
		@include flex-direction(column);
		@include flex-align-items(center);
		height: auto;

		.sc_blogger_item_featured {
			order: 1;
			width: 100% !important;
		}
		.sc_blogger_item_content {
			order: 2;
			width: 100% !important;
		}
	}

	/* Layout: Wide */
	.sc_blogger_item_wide,
	.sc_blogger_item_wide.sc_blogger_item_with_image .sc_blogger_item_body {
		@include flex-direction(column);
	}
	.sc_blogger_item_wide .sc_blogger_item_header,
	.sc_blogger_item_wide .sc_blogger_item_body,
	.sc_blogger_item_wide .sc_blogger_item_featured,
	.sc_blogger_item_wide .sc_blogger_item_content {
		width: 100% !important;
		padding: 0 !important;
	}
	.sc_blogger_item_wide .sc_blogger_item_header { order: 1; margin-bottom: 1em; }
	.sc_blogger_item_wide .sc_blogger_item_body { order: 2; }
	.sc_blogger_item_wide .sc_blogger_item_featured { order: 1; }
	.sc_blogger_item_wide .sc_blogger_item_content { order: 2; margin-top: 1.5em; }

	/* Layout: Announce */
	.sc_blogger_news_announce {
		.sc_blogger_item + .sc_blogger_item {
			margin-top: 2em;
		}
		.sc_blogger_grid_wrap {
			display: block;
		}
	}
	
	/* Layout: Magazine */
	.sc_blogger_news_magazine {
		.sc_blogger_grid_wrap:not([class*="sc_blogger_grid_columns_"]) .sc_blogger_item:first-child,
		.sc_blogger_grid_wrap[class*="sc_blogger_grid_columns_"] .sc_blogger_item:first-child {
			padding-bottom: 1em;
			margin-bottom: 1em;
			border-bottom: 1px solid #ddd;
		}
		.sc_blogger_grid_wrap:not([class*="sc_blogger_grid_columns_"]) .sc_blogger_item:last-child,
		.sc_blogger_grid_wrap[class*="sc_blogger_grid_columns_"] .sc_blogger_item:last-child {
			padding-bottom: 0;
			margin-bottom: 0;
			border-bottom: none;
		}
		.sc_blogger_grid_wrap .sc_blogger_item {
			float: none !important;
			width: 100% !important;
			margin-right: 0 !important;
		}
		.sc_blogger_grid_wrap.sc_blogger_grid_columns_3 .sc_blogger_item:nth-child(n+2) .sc_blogger_item_title + .sc_blogger_item_meta {
			display: block;
		}
	}

	/* Layout: Panel */
	.sc_blogger_panel {
		.sc_blogger_item {
			padding: 10em 1.5em 1.5em;
		}

		.sc_blogger_item + .sc_blogger_item,
		[class*="trx_addons_column-"] + [class*="trx_addons_column-"] .sc_blogger_item {
			border-left: none;
			border-top: 1px solid rgba(255,255,255,0.2);
		}
	}
}