@import "../../css/_mixins.scss";
@import "../../css/_trx_addons.vars.scss";


//@mixin reviews--sm() {
@media #{$media_sm} {
	/* Reviews */
	.trx_addons_reviews_block_short {
		float: none !important;
		margin: 1em auto !important;
	}
	.trx_addons_reviews_block_detailed .trx_addons_reviews_block_mark_wrap {
		width: 40%;
	}
	.trx_addons_reviews_block_detailed .trx_addons_reviews_block_summary {
		width: 60%;
	}
}

//@mixin reviews--xs() {
@media #{$media_xs} {
	/* Reviews */
	.trx_addons_reviews_block_short {
		width: 280px;
	}
	.trx_addons_reviews_block_detailed .trx_addons_reviews_block_mark_wrap,
	.trx_addons_reviews_block_detailed .trx_addons_reviews_block_summary {
		display: block;
		width: 100%;
	}
	.trx_addons_reviews_block_detailed .trx_addons_reviews_block_summary {
		margin-top: 1.5em;
	}
	.trx_addons_reviews_block_detailed .trx_addons_reviews_block_positives,
	.trx_addons_reviews_block_detailed .trx_addons_reviews_block_negatives {
		display: block;
		width: 100%;
	}
	.trx_addons_reviews_block_detailed .trx_addons_reviews_block_negatives {
		margin-top: 1.5em;
	}
}
