.sp-eab-responsive-picker {
    margin-left: 10px;
}

.sp-eab-units-indicator {
    position: relative;
    color: #8c8f94;

    // unit button.
    .sp-eab-units-btn {
        box-shadow: 2px 2px 8px 0px rgba(0, 0, 0, 0.15);
        position: absolute;
        z-index: 999;
        margin-top: 2px;
        opacity: 0;
        visibility: hidden;
        transition: 0.3s;

        button.components-button {
            text-transform: lowercase;

            &:hover {
                color: #3c434a;
                background-color: #FAE9E8;
            }

            &.active {
                color: #fff;
                background-color: var(--eab-primary-color);

                &:hover {
                    color: #fff;
                }
            }
        }
    }

    &:hover {
        span {
            border-color: var(--eab-primary-color);
            color: var(--eab-primary-color);

            svg {
                fill: var(--eab-primary-color);
            }
        }

        .sp-eab-units-btn {
            opacity: 1;
            visibility: visible;
        }
    }

    span {
        font-size: 10px;
        line-height: 1;
        width: fit-content;
        padding: 4px;
        height: 20px;
        border: 1px solid #8c8f94;
        border-radius: 2px;
        text-transform: lowercase;
        display: flex;
        align-items: center;
        justify-content: center;
        cursor: pointer;

        svg {
            fill: #8c8f94;
        }
    }

    span.box-unit {
        width: 45px !important;
    }

    button {
		padding: 0 4px;
		height: 20px;
		width: 100%;
		display: flex;
		justify-content: center;
		background-color: #fff;
		font-size: 10px;
		border: none;
		color: #8c8f94;
		border-radius: 0;
		box-shadow: none;

        &:focus:not(:disabled) {
            outline: none;
            box-shadow: none;
        }
    }

    &.box {
        .sp-eab-units-btn {
            button {
                width: 45px;
            }
        }
    }
}