/* Styles for controls in the Elementor Editor
------------------------------------------------ */

/* Add brand to widgets */
#elementor-panel-elements-wrapper .elementor-element .trx_addons_elementor_widget_icon:after {
	content: "TRX";
	font-family: Roboto,Arial,Helvetica,Verdana,sans-serif;
	font-size: 9px;
	font-weight: bold;
	padding: 0.2em 0.5em;
	background-color: #aedf49;
	color: #000;
	/*
	border-width: 0 1px 1px 0;
	border-color: #e0e0e0;
	border-style: solid;
	*/
	position: absolute;
	top: 0;
	left: 0;
}
#elementor-panel-elements-wrapper .elementor-element:hover .trx_addons_elementor_widget_icon:after {
	background: #000;
	color: #fff;
}

/* Make each panel category as accordion */
#elementor-panel-categories .elementor-panel-category-title {
	color: #556068;
	padding: 17px 0;
	-webkit-transition: color 0.3s ease-out;
	    -ms-transition: color 0.3s ease-out;
	        transition: color 0.3s ease-out;
}
#elementor-panel-categories .elementor-panel-category-title:hover {
	color: #8b949a;
}
.elementor-panel .elementor-panel-category:not(.elementor-active):after {
	display: none;
}

/* Hide native Elementor's responsive params */
body.replace_hide_on_xxx .elementor-control-hide_widescreen,
body.replace_hide_on_xxx .elementor-control-hide_laptop,
body.replace_hide_on_xxx .elementor-control-hide_tablet_extra,
body.replace_hide_on_xxx .elementor-control-hide_mobile_extra,
body.replace_hide_on_xxx .elementor-control-hide_desktop,
body.replace_hide_on_xxx .elementor-control-hide_tablet,
body.replace_hide_on_xxx .elementor-control-hide_mobile {
	display: none !important;
}

/* Icons selector */
.elementor-control .trx_addons_icon_selector + .trx_addons_list_icons {
	left: 0 !important;
}
.elementor-control .trx_addons_icon_selector + .trx_addons_list_icons span {
	width: 2.08em;
}

/* Image selector */
.elementor-control .elementor-control-media__preview {
	background-repeat: no-repeat;
	background-size: contain;
}

/* Date_Time Control */
.datepicker_header a.icon-home:before {
	display: none;
}

/* Color picker */
.elementor-control .iris-border .iris-picker-inner {
	margin-right: -1px;
}
.elementor-control .wp-picker-container input[type="text"].wp-color-picker {
	min-height: 14px;
}
