<?php
/**
 * Widget: Socials (Gutenberg support)
 *
 * @package ThemeREX Addons
 * @since v1.0
 */

// Don't load directly
if ( ! defined( 'TRX_ADDONS_VERSION' ) ) {
	exit;
}



// Gutenberg Block
//------------------------------------------------------

// Add scripts and styles for the editor
if ( ! function_exists( 'trx_addons_gutenberg_sc_widget_socials_editor_assets' ) ) {
	add_action( 'enqueue_block_editor_assets', 'trx_addons_gutenberg_sc_widget_socials_editor_assets', TRX_ADDONS_GUTENBERG_EDITOR_BLOCK_REGISTRATION_PRIORITY );
	function trx_addons_gutenberg_sc_widget_socials_editor_assets() {
		if ( trx_addons_exists_gutenberg() && trx_addons_get_setting( 'allow_gutenberg_blocks' ) ) {
			// Scripts
			wp_enqueue_script(
				'trx-addons-gutenberg-editor-block-widget-socials',
				trx_addons_get_file_url( TRX_ADDONS_PLUGIN_WIDGETS . 'socials/gutenberg/socials.gutenberg-editor.js' ),
				trx_addons_block_editor_dependencis(),
				filemtime( trx_addons_get_file_dir( TRX_ADDONS_PLUGIN_WIDGETS . 'socials/gutenberg/socials.gutenberg-editor.js' ) ),
				true
			);
		}
	}
}

// Block register
if ( ! function_exists( 'trx_addons_sc_widget_socials_add_in_gutenberg' ) ) {
	add_action( 'init', 'trx_addons_sc_widget_socials_add_in_gutenberg' );
	function trx_addons_sc_widget_socials_add_in_gutenberg() {
		if ( trx_addons_exists_gutenberg() && trx_addons_get_setting( 'allow_gutenberg_blocks' ) ) {
			register_block_type(
				'trx-addons/widget-socials',
				apply_filters('trx_addons_gb_map', array(
					'attributes'      => array_merge(
						array(
							'title'       => array(
								'type'    => 'string',
								'default' => '',
							),
							'description' => array(
								'type'    => 'string',
								'default' => '',
							),
							'align'       => array(
								'type'    => 'string',
								'default' => 'left',
							),
							'type'        => array(
								'type'    => 'string',
								'default' => 'socials',
							),
						),
						trx_addons_gutenberg_get_param_id()
					),
					'render_callback' => 'trx_addons_gutenberg_sc_widget_socials_render_block',
				), 'trx-addons/widget-socials' )
			);
		}
	}
}

// Block render
if ( ! function_exists( 'trx_addons_gutenberg_sc_widget_socials_render_block' ) ) {
	function trx_addons_gutenberg_sc_widget_socials_render_block( $attributes = array() ) {
		return trx_addons_sc_widget_socials( $attributes );
	}
}


// Add shortcode's specific lists to the JS storage
if ( ! function_exists( 'trx_addons_sc_socials_gutenberg_sc_params' ) ) {
	add_filter( 'trx_addons_filter_gutenberg_sc_params', 'trx_addons_sc_socials_gutenberg_sc_params' );
	function trx_addons_sc_socials_gutenberg_sc_params( $vars = array() ) {

		if (!isset($vars['sc_socials_types'])) {
			// If editor is active now
			$is_edit_mode = trx_addons_is_post_edit();

			$vars['sc_socials_types'] = !$is_edit_mode ? array() : trx_addons_get_list_sc_socials_types();
		}

		return $vars;
	}
}
