body.allow_lazy_load {
	.post_featured [class*='_inline_'],
	.post_featured[class*='_inline_'],
	.post_thumb[class*='_inline_'],
	.banner_wrap[class*='_inline_'],
	.sc_panel_thumb[class*='_inline_'] {	
		&:not([class*="trx_addons_inline_"]):not(.lazyload_inited) {
	    	background-image:  url(images/placeholder.png) !important;
		}
	}

	img,
	[data-trx-lazyload-style],
	.post_featured [class*='_inline_'],
	.post_featured[class*='_inline_'],
	.post_thumb[class*='_inline_'],
	.banner_wrap[class*='_inline_'],
	.sc_panel_thumb[class*='_inline_'] {	
		&:not([class*="trx_addons_inline_"]).lazyload_loading {
	    	opacity: 0 !important;
		}
	}

	.page_content_wrap {		
		.elementor-element[data-settings],
		.elementor-element[data-settings] > .elementor-column-wrap {	
			&:not(.lazyload_inited) {
		    	background-image: none !important;		
			}
		}
	}
}