/* Extended Attributes
------------------------------------------------ */
.woocommerce div.product form.cart .variations td {
  display: block;
  width: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.woocommerce div.product form.cart .variations tr + tr .label {
  padding: 1em 0 0;
}

.trx_addons_attrib_item {
  cursor: pointer !important;
}

.trx_addons_attrib_item span {
  overflow: hidden;
  display: block;
}

/* Image */
.trx_addons_attrib_item.trx_addons_attrib_image {
  vertical-align: top;
  display: -webkit-inline-flex;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  margin: 0 0.5em 5px 0;
  padding: 5px;
  border: 1px solid #e0e2e5;
  background-color: #fff;
}

.trx_addons_attrib_item.trx_addons_attrib_image img {
  width: 70px;
  height: auto;
}

/* Color */
.trx_addons_attrib_item.trx_addons_attrib_color {
  display: inline-block;
  vertical-align: top;
  margin: 0 0.5em 5px 0;
  padding: 3px;
  border: 1px solid #e0e2e5;
  background-color: #fafafa;
}

.trx_addons_attrib_item.trx_addons_attrib_color span {
  display: block;
  width: 30px;
  height: 30px;
}

/* Button */
.trx_addons_attrib_item.trx_addons_attrib_button {
  display: inline-block;
  vertical-align: top;
  margin: 0 0.5em 5px 0;
  padding: 3px;
  border: 1px solid #e0e2e5;
  background-color: #fafafa;
}

.trx_addons_attrib_item.trx_addons_attrib_button span {
  padding: 0.5em 1.5em;
}

/* Selected items */
.trx_addons_attrib_item.trx_addons_attrib_selected {
  background-color: #f0f0f0;
  border-color: red;
}

/* Disabled items */
.trx_addons_attrib_item.trx_addons_attrib_disabled {
  cursor: not-allowed !important;
}

.trx_addons_attrib_item.trx_addons_attrib_disabled span {
  position: relative;
}

.trx_addons_attrib_item.trx_addons_attrib_disabled span:before,
.trx_addons_attrib_item.trx_addons_attrib_disabled span:after {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 50%;
  left: -20%;
  width: 140%;
  height: 1px;
  background-color: #f0f0f0;
  -webkit-transform: rotate(-45deg);
  -ms-transform: rotate(-45deg);
  transform: rotate(-45deg);
}

.trx_addons_attrib_item.trx_addons_attrib_disabled span:after {
  -webkit-transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  transform: rotate(45deg);
}

/* Attributes in the products list */
.trx_addons_product_attributes {
  order: 2;
  margin-top: 1em;
  clear: both;
  padding-bottom: 2px;
}
.product.add-to-wishlist-before_image .trx_addons_product_attributes {
  margin-top: 0;
}
.trx_addons_product_attributes .trx_addons_product_attribute {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.trx_addons_product_attributes .trx_addons_product_attribute .trx_addons_product_attribute_label {
  display: inline-block;
  vertical-align: top;
  margin-right: 0.25em;
}
.trx_addons_product_attributes .trx_addons_product_attribute .trx_addons_product_attribute_label:after {
  content: ':';
}
.trx_addons_product_attributes .trx_addons_product_attribute .trx_addons_product_attribute_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  margin: 0 0.15em;
  border: none;
}
.trx_addons_product_attributes .trx_addons_product_attribute .trx_addons_product_attribute_item_action_swap {
  display: block;
  position: relative;
}
.trx_addons_product_attributes .trx_addons_product_attribute .trx_addons_product_attribute_item_disabled > a {
  opacity: 0.5;
  cursor: not-allowed;
}
.trx_addons_product_attributes .trx_addons_product_attribute .trx_addons_product_attribute_item_active .trx_addons_product_attribute_item_action_swap:after {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  border: 1px solid rgba(128, 128, 128, 0.75);
  pointer-events: none;
}
.trx_addons_product_attributes .trx_addons_product_attribute.trx_addons_product_attribute_type_color .trx_addons_product_attribute_item_active .trx_addons_product_attribute_item_action_swap:after {
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  position: absolute;
  z-index: 1;
  top: -2px;
  right: -2px;
  bottom: -2px;
  left: -2px;
}
.trx_addons_product_attributes .trx_addons_product_attribute.trx_addons_product_attribute_type_image .trx_addons_product_attribute_item_active .trx_addons_product_attribute_item_action_swap:after {
  -webkit-border-radius: 2px;
  -ms-border-radius: 2px;
  border-radius: 2px;
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
}
.trx_addons_product_attributes .trx_addons_product_attribute.trx_addons_product_attribute_type_button .trx_addons_product_attribute_item_active .trx_addons_product_attribute_item_action_swap:after, .trx_addons_product_attributes .trx_addons_product_attribute.trx_addons_product_attribute_type_select .trx_addons_product_attribute_item_active .trx_addons_product_attribute_item_action_swap:after {
  border-top: none;
  border-left: none;
  border-right: none;
  bottom: 3px;
}
.trx_addons_product_attributes .trx_addons_product_attribute.trx_addons_product_attribute_type_color .trx_addons_product_attribute_item {
  position: relative;
}
.trx_addons_product_attributes .trx_addons_product_attribute.trx_addons_product_attribute_type_color .trx_addons_product_attribute_item .trx_addons_product_attribute_item_inner {
  display: block;
  width: 1em;
  height: 1em;
  line-height: 1em;
  text-align: center;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  border: 1px solid rgba(192, 192, 192, 0.5);
}
.trx_addons_product_attributes .trx_addons_product_attribute.trx_addons_product_attribute_type_image .trx_addons_product_attribute_item {
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
}
.trx_addons_product_attributes .trx_addons_product_attribute.trx_addons_product_attribute_type_image .trx_addons_product_attribute_item img {
  -webkit-border-radius: 2px;
  -ms-border-radius: 2px;
  border-radius: 2px;
  border: 1px solid rgba(192, 192, 192, 0.5);
  box-sizing: border-box;
}
.trx_addons_product_attributes .trx_addons_product_attribute.trx_addons_product_attribute_type_image .trx_addons_product_attribute_item img:hover {
  transform: none !important;
}
.trx_addons_product_attributes .trx_addons_product_attribute.trx_addons_product_attribute_type_button .trx_addons_product_attribute_item {
  -webkit-border-radius: 2px;
  -ms-border-radius: 2px;
  border-radius: 2px;
  border: 1px solid rgba(192, 192, 192, 0.5);
  padding: 0 4px;
  font-size: 0.8em;
  line-height: 1.75em;
}

/* Child categories in the header or in the tools area */
.trx_addons_woocommerce_child_categories {
  margin-top: 1em;
}

.trx_addons_woocommerce_child_categories .categories_list,
.trx_addons_woocommerce_tools .categories_list {
  overflow-x: auto;
  overflow-y: hidden;
}
.trx_addons_woocommerce_child_categories .categories_list .sc_button_wrap,
.trx_addons_woocommerce_tools .categories_list .sc_button_wrap {
  white-space: nowrap;
}

/* WooCommerce tools area - widgets above products loop */
.trx_addons_woocommerce_tools {
  padding-bottom: 1em;
  margin-bottom: 2em;
  border-bottom: 1px solid #f0f0f0;
}
.list_products_header .trx_addons_woocommerce_tools {
  margin-top: 2em;
}
.trx_addons_woocommerce_tools .widget + .widget {
  margin-top: 2em;
}
.trx_addons_woocommerce_tools .widget_layered_nav_filters {
  margin-top: 1.25em;
}
.trx_addons_woocommerce_tools .widget_layered_nav_filters > ul > li {
  padding: 0.25em 0.5em 0.25em 0;
}
.trx_addons_woocommerce_tools ~ ul.products {
  position: relative;
  z-index: 1;
}

/* Widget "WooCommerce Search"
------------------------------------------------------ */
.trx_addons_woocommerce_search .trx_addons_woocommerce_search_button:before {
  margin-right: 0.5em;
  vertical-align: middle;
  text-align: center;
}

.trx_addons_woocommerce_search_loading {
  position: relative;
  z-index: 1;
}
.trx_addons_woocommerce_search_loading .trx_addons_loading {
  position: absolute;
  z-index: 1000;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: rgba(255, 255, 255, 0.5);
}
.trx_addons_woocommerce_search_loading .trx_addons_woocommerce_search_form_fields_wrap > .trx_addons_loading {
  display: none;
}
.trx_addons_woocommerce_search_loading .trx_addons_woocommerce_search_form_fields_wrap_opened > .trx_addons_loading {
  display: block;
}

/* Type: Filter */
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all {
  display: none;
  color: #23282d;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all:before {
  content: '\e922';
  font-family: "trx_addons_icons";
  margin-right: 0.3em;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_close {
  display: none;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap.trx_addons_woocommerce_search_form_fields_filled .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all {
  display: block;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_button_show {
  display: none;
  text-align: center;
  margin-top: 2em;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_button_show .trx_addons_woocommerce_search_button_show_total {
  display: inline-block;
  vertical-align: middle;
  margin: -3px 0 0 0.5em;
  font-size: 0.8571em;
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: #23282d;
  color: #fff;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field {
  display: block;
  margin: 0 0 1em 0;
  position: relative;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title {
  font-weight: inherit;
  cursor: pointer;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title:hover, .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title:focus {
  cursor: pointer;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title.sc_form_field_title_filled .sc_form_field_title_caption {
  font-weight: bold;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_arrow {
  display: inline-block;
  margin-left: 1em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_arrow:before {
  content: '\e882';
  font-family: "trx_addons_icons";
  display: block;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_opened .sc_form_field_arrow:before {
  -webkit-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_selected_items {
  display: block;
  color: #9099a2;
  font-size: 0.8571em;
  line-height: 1.25em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap {
  display: none;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  padding: 1em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_item {
  display: block;
  padding: 0.25em 0.5em;
  -webkit-transition: color 0.3s ease, background-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease;
  cursor: pointer;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_item:hover, .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_item:focus {
  background-color: #f0f0f0;
  cursor: pointer;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_item .sc_form_field_item_total {
  display: inline-block;
  vertical-align: top;
  margin: -0.5em 0 0 0.5em;
  font-size: 0.75em;
  color: #9099a2;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: space-between;
  -ms-flex-pack: space-between;
  justify-content: space-between;
  margin-top: 1em;
  font-size: 0.92857em;
  color: #9099a2;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_clear,
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_select_all {
  color: #23282d;
  text-decoration: underline;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_clear:hover,
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_select_all:hover {
  color: #a00000;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_clear {
  display: none;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_buttons {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: space-between;
  -ms-flex-pack: space-between;
  justify-content: space-between;
  margin-top: 1em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap .sc_form_field_buttons .sc_button {
  padding: 0.5em 2.5em;
  text-transform: none;
  margin: 0;
  width: 48%;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title_filled ~ .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_clear {
  display: inline-block;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title_filled ~ .sc_form_field_wrap .sc_form_field_items_selected .sc_form_field_items_selected_select_all {
  display: none;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_text .sc_form_field_wrap {
  margin: 0;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_text .sc_form_field_wrap .sc_form_field_input {
  padding: 0 0 0.25em 0;
  border: none;
  background-color: transparent;
  border-bottom: 1px solid #23282d;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_text .sc_form_field_wrap .sc_form_field_buttons {
  margin-top: 2em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_slider .sc_form_field_wrap, .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_range .sc_form_field_wrap {
  margin: 0;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_slider .sc_form_field_wrap .trx_addons_range_slider, .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_range .sc_form_field_wrap .trx_addons_range_slider {
  display: block;
  margin: 1.5em 0.5em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_slider .sc_form_field_wrap .trx_addons_range_result, .trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_range .sc_form_field_wrap .trx_addons_range_result {
  display: block;
  margin-top: 0.5em;
  font-size: 0.92857em;
  color: #9099a2;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item {
  position: relative;
  margin: 0 -0.5em;
  display: block;
  overflow: hidden;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_level_1 {
  padding-left: 1em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_level_2 {
  padding-left: 1.5em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_level_3 {
  padding-left: 2em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_level_4 {
  padding-left: 2.5em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_level_5 {
  padding-left: 3em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_level_6 {
  padding-left: 3.5em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_level_7 {
  padding-left: 4em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_level_8 {
  padding-left: 4.5em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item .sc_form_field_item_total {
  vertical-align: top;
  margin: 0;
  position: absolute;
  z-index: 1;
  top: 50%;
  right: 0.75em;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  color: #9099a2;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item .star-rating {
  float: left;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item .star-rating span:before {
  color: #23282d;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item[data-value="4"] .star-rating > span {
  width: 80%;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item[data-value="3"] .star-rating > span {
  width: 60%;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item[data-value="2"] .star-rating > span {
  width: 40%;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select .sc_form_field_wrap .sc_form_field_item[data-value="1"] .star-rating > span {
  width: 20%;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select:not([data-multiple="1"]) .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_checked {
  font-weight: bold;
  text-decoration: underline;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select[data-multiple="1"] .sc_form_field_wrap .sc_form_field_item {
  padding-left: 2.25em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select[data-multiple="1"] .sc_form_field_wrap .sc_form_field_item:before {
  content: ' ';
  font-family: "trx_addons_icons";
  display: block;
  width: 1.25em;
  height: 1.25em;
  line-height: 1.25em;
  text-align: center;
  line-height: 1.2em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  border: 1px solid #e0e2e5;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 0.5em;
  margin-top: -0.6em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_select[data-multiple="1"] .sc_form_field_wrap .sc_form_field_item.sc_form_field_item_checked:before {
  content: '\e8bd';
  background-color: #23282d;
  border-color: #23282d;
  color: #fff;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  margin: 0 -0.5em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  width: 25%;
  height: auto;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  max-width: 6em;
  overflow: hidden;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item .sc_form_field_item_image {
  display: block;
  width: 3em;
  height: 3em;
  line-height: 3em;
  text-align: center;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  -webkit-transition: border-color 0.3s ease;
  -ms-transition: border-color 0.3s ease;
  transition: border-color 0.3s ease;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  border: 1px solid rgba(0, 0, 0, 0.15);
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_image {
  position: relative;
  border: none;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_image:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: -3px;
  right: -3px;
  bottom: -3px;
  left: -3px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  border: 1px solid #e0e2e5;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_color .sc_form_field_items .sc_form_field_item .sc_form_field_item_label {
  display: block;
  margin-top: 0.25em;
  font-size: 0.75em;
  line-height: 1.6em;
  text-align: center;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  margin: 0 -0.5em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  width: 33.3333%;
  height: auto;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  max-width: 6em;
  overflow: hidden;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item .sc_form_field_item_image {
  display: block;
  width: 100%;
  height: 3.5em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 4px;
  -ms-border-radius: 4px;
  border-radius: 4px;
  -webkit-transition: border-color 0.3s ease;
  -ms-transition: border-color 0.3s ease;
  transition: border-color 0.3s ease;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  border: 1px solid #f7f7f7;
  background-position: center;
  background-size: contain;
  background-repeat: no-repeat;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_image {
  border-color: #e0e2e5;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_image .sc_form_field_items .sc_form_field_item .sc_form_field_item_label {
  display: block;
  margin-top: 0.25em;
  font-size: 0.75em;
  line-height: 1.6em;
  text-align: center;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  margin: 0 -0.25em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item {
  display: inline-block;
  vertical-align: top;
  text-align: center;
  overflow: hidden;
  width: 33.3333%;
  max-width: 6em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  padding: 0.25em 0.25em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item:hover {
  background-color: transparent !important;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item .sc_form_field_item_label {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-transition: border-color 0.3s ease;
  -ms-transition: border-color 0.3s ease;
  transition: border-color 0.3s ease;
  width: 100%;
  height: 3em;
  border: 1px solid #f0f0f0;
  font-size: 0.75em;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item .sc_form_field_item_label:hover {
  background-color: #f0f0f0;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item.sc_form_field_item_checked .sc_form_field_item_label {
  border-color: #23282d;
}
.trx_addons_woocommerce_search_type_filter .sc_form_field.sc_form_field_button .sc_form_field_items .sc_form_field_item .sc_form_field_item_total {
  margin-top: -1em;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_button_filters.sc_button {
  display: none;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_button_filters:before {
  display: inline-block;
  vertical-align: middle;
  margin-right: 0.3em;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_button_filters .trx_addons_woocommerce_search_button_filters_total {
  display: inline-block;
  vertical-align: middle;
  margin: -3px 0 0 0.5em;
  font-size: 0.8571em;
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: #23282d;
  color: #fff;
}
.trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_button_filters .trx_addons_woocommerce_search_button_filters_total_empty {
  display: none;
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: space-between;
  -ms-flex-pack: space-between;
  justify-content: space-between;
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_header {
  order: 2;
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field {
  display: inline-block;
  vertical-align: top;
  margin: 0 1em 0 0;
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title:hover .sc_form_field_title_caption {
  text-decoration: underline;
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_selected_items {
  display: none;
}
.trx_addons_woocommerce_tools .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap {
  position: absolute;
  z-index: 100;
  top: 2em;
  left: 0;
  width: 18em;
  height: auto;
  background-color: #fff;
  border: 1px solid #e0e2e5;
  max-height: 21em;
  overflow-x: hidden;
  overflow-y: auto;
}
.sidebar .trx_addons_woocommerce_search_type_filter .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all {
  padding: 0.75em 0;
  border-bottom: 1px solid #9099a2;
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field {
  margin: 0;
  border-bottom: 1px solid #9099a2;
  /* &:not(.sc_form_field_text):not(.sc_form_field_range) .trx_addons_search_buttons { */
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field:last-child {
  border-bottom: none;
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title {
  padding: 0.75em 0;
  position: relative;
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_title .sc_form_field_arrow {
  position: absolute;
  z-index: 1;
  top: 0.75em;
  right: 0;
  margin-left: 0;
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .sc_form_field_wrap {
  border: none;
  background-color: transparent;
  padding-left: 0;
  padding-right: 0;
  padding-top: 0;
}
.sidebar .trx_addons_woocommerce_search_type_filter .sc_form_field .trx_addons_search_buttons {
  display: none;
}
.sidebar .trx_addons_woocommerce_search_type_filter.trx_addons_woocommerce_search_apply .trx_addons_woocommerce_search_button_show {
  -webkit-position: sticky;
  position: -webkit-sticky;
  position: sticky;
  z-index: 1;
  bottom: 0;
}
.sidebar .trx_addons_woocommerce_search_type_filter.trx_addons_woocommerce_search_apply .trx_addons_woocommerce_search_form_fields_changed .trx_addons_woocommerce_search_button_show {
  display: block;
}

/* Type: Form */
.trx_addons_woocommerce_search_type_form .trx_addons_woocommerce_search_last_text {
  display: block;
  margin-bottom: 1.3em;
}

/* Type: Inline */
.trx_addons_woocommerce_search_type_inline {
  font-size: 1.5em;
  line-height: 1.7em;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_options,
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_button {
  display: inline-block;
  vertical-align: top;
  width: 80%;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_button {
  width: 20%;
  text-align: right;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field input[type="text"],
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field .trx_addons_woocommerce_search_form_field_label {
  width: auto;
  border: none;
  border-bottom: 2px solid #e0e2e5;
  background-color: transparent !important;
  color: #9099a2;
  padding: 0.2em;
  margin: 0 0.3em;
  -webkit-border-radius: 0 !important;
  -ms-border-radius: 0 !important;
  border-radius: 0 !important;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field input[type="text"] {
  width: 4em;
  text-align: center;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field .trx_addons_woocommerce_search_form_field_label {
  cursor: pointer;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field_type_select {
  position: relative;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field_list {
  display: none;
  position: absolute;
  z-index: 10;
  top: 2em;
  left: 50%;
  width: 240px;
  height: auto;
  font-size: 0.6667em;
  line-height: 1.5em;
  margin-left: -120px;
  max-height: 280px;
  overflow-y: auto;
  overflow-x: hidden;
  border: 1px solid #e0e2e5;
  background-color: #f7f7f7;
  padding: 0;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field_list li {
  cursor: pointer;
  display: block;
  padding: 0.5em 1em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.trx_addons_woocommerce_search_type_inline .trx_addons_woocommerce_search_form_field_list li:before {
  display: none;
}

/* Widget "WooCommerce Title"
------------------------------------------------------ */
.trx_addons_woocommerce_title .entry-title {
  margin: 0;
}

/* Slider with products
------------------------------------------------------ */
.woocommerce .slider_container ul.products.slider-wrapper,
.woocommerce-page .slider_container ul.products.slider-wrapper {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  margin: 0;
}
.woocommerce .slider_container ul.products.slider-wrapper li.product,
.woocommerce-page .slider_container ul.products.slider-wrapper li.product {
  width: 100%;
  padding: 0;
}

/* Third-party plugins
------------------------------------------------------ */
/* YITH Magnifier */
.yith_magnifier_zoom_wrap .yith_magnifier_zoom_magnifier {
  border-width: 1px;
  margin-left: 4px;
}

.yith_magnifier_gallery li + li {
  padding-left: 20px;
}

.yith_magnifier_gallery li a {
  margin-left: 0;
  margin-right: 0;
}

/* YITH Quick View */
.yith-wcqv-main {
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  padding: 3em;
}

/* WOO Social Butoons */
.woocommerce .product .summary .woo-social-buttons span.nocount > span,
.woocommerce .product .summary .woo-social-buttons span.hcount > span {
  vertical-align: top;
}

/*# sourceMappingURL=woocommerce.css.map */
