/* Icons */
.sc_icons {
  position: relative;
  padding-top: 0.0001px;
}

.sc_icons_columns_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}

.sc_icons_slider .sc_icons_item,
.sc_icons_columns_wrap .sc_icons_item {
  display: inline-block;
  vertical-align: top;
  width: 100%;
  height: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.sc_icons_slider .sc_icons_item {
  margin-bottom: 0 !important;
}

.sc_icons .sc_icons_item {
  position: relative;
}

.sc_icons.sc_align_left .sc_icons_item {
  text-align: left;
}

.sc_icons.sc_align_center .sc_icons_item {
  text-align: center;
}

.sc_icons.sc_align_right .sc_icons_item {
  text-align: right;
}

.sc_icons .sc_icons_item > * {
  margin: 0;
}

.sc_icons .sc_icons_icon {
  color: #efa758;
  position: relative;
  z-index: 2;
  display: inline-block;
  width: auto;
}

.sc_icons_icon.sc_icons_char:before,
.sc_icons_icon.sc_icons_char > span:before {
  content: attr(data-char);
  font-weight: 700;
}

.sc_icon_type_svg.sc_icon_animation {
  visibility: hidden;
}

.sc_icon_type_svg svg {
  stroke: currentColor;
  fill: currentColor;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.sc_icon_type_svg.sc_icon_animation svg {
  fill: none !important;
}

.sc_icons .sc_icons_icon:before,
.sc_icons .sc_icons_icon > span:before {
  font-size: 6em;
  line-height: 1.1em !important;
}

.sc_icon_type_svg svg,
.sc_icon_type_svg object {
  width: 6em;
  height: 6em;
  display: inline-block;
  overflow: visible;
  margin-bottom: -0.1em;
}

.sc_icons .sc_icons_image img {
  max-width: 75%;
}

.sc_icons_size_small .sc_icons_icon:before,
.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 4em;
  line-height: 1.1em !important;
}

.sc_icons_size_small .sc_icon_type_svg svg,
.sc_icons_size_small .sc_icon_type_svg object {
  width: 4em;
  height: 4em;
}

.sc_icons_size_large .sc_icons_icon:before,
.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 8em;
  line-height: 1.1em !important;
}

.sc_icons_size_large .sc_icon_type_svg svg,
.sc_icons_size_large .sc_icon_type_svg object {
  width: 8em;
  height: 8em;
}

.sc_icons .sc_icons_icon > span {
  display: inline-block;
  opacity: 0;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: auto;
}

.sc_icons .sc_icons_icon,
.sc_icons .sc_icons_item_title {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.sc_icons .sc_icons_item_title span,
.sc_icons .sc_icons_item_description span {
  display: block;
}

.sc_icons_item_title {
  font-size: 1.25em;
  line-height: 1.3em;
  font-weight: 400;
  font-style: normal;
  text-transform: uppercase;
  letter-spacing: 1px;
  margin: 0;
}

.sc_icons_item_description {
  font-size: 1em;
  line-height: 1.6em;
}

.sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.5em;
}

.sc_icons .sc_icons_item_link {
  display: block;
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}

/* Style Default */
.sc_icons_default .sc_icons_icon + .sc_icons_item_details,
.sc_icons_default .sc_icons_image + .sc_icons_item_details {
  margin-top: 1em;
}

/* Style Modern */
.sc_icons_modern {
  position: relative;
}

.sc_icons_modern .sc_icons_icon,
.sc_icons_modern .sc_icons_image {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
}

.sc_icons_modern .sc_icons_image {
  max-width: 6em;
  overflow: hidden;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_icons_modern .sc_icons_image img {
  max-width: none;
  height: 6em;
}

.sc_icons_modern.sc_icons_size_small .sc_icons_image {
  max-width: 4em;
}
.sc_icons_modern.sc_icons_size_small .sc_icons_image img {
  height: 4em;
}

.sc_icons_modern.sc_icons_size_large .sc_icons_image {
  max-width: 8em;
}
.sc_icons_modern.sc_icons_size_large .sc_icons_image img {
  height: 8em;
}

.sc_icons_modern.sc_align_right .sc_icons_icon,
.sc_icons_modern.sc_align_right .sc_icons_image {
  left: auto;
  right: 0;
}

.sc_icons_modern .sc_icons_item_details {
  min-height: 6em;
  padding-left: 8em;
}

.sc_icons_modern.sc_align_right .sc_icons_item_details {
  padding-left: 0;
  padding-right: 8em;
}

.sc_icons_modern.sc_icons_size_small .sc_icons_item_details {
  min-height: 4em;
  padding-left: 6em;
}

.sc_icons_modern.sc_icons_size_small.sc_align_right .sc_icons_item_details {
  padding-left: 0;
  padding-right: 6em;
}

.sc_icons_modern.sc_icons_size_large .sc_icons_item_details {
  min-height: 8em;
  padding-left: 10em;
}

.sc_icons_modern.sc_icons_size_large.sc_align_right .sc_icons_item_details {
  padding-left: 0;
  padding-right: 10em;
}

/* Hover effects */
.sc_icons .sc_icons_item_linked:hover .sc_icons_icon > span {
  -webkit-animation: icons-zoom 0.25s ease-out;
  -ms-animation: icons-zoom 0.25s ease-out;
  animation: icons-zoom 0.25s ease-out;
}

.sc_icons .sc_icons_item_linked:hover .sc_icons_icon > svg {
  -webkit-transform: scale(1.1, 1.1);
  -ms-transform: scale(1.1, 1.1);
  transform: scale(1.1, 1.1);
}

.sc_icons .sc_icons_item_linked .sc_icons_icon + .sc_icons_item_title,
.sc_icons .sc_icons_item_linked .sc_icons_image + .sc_icons_item_title,
.sc_icons .sc_icons_item_linked .sc_icons_icon + .sc_icons_item_description,
.sc_icons .sc_icons_item_linked .sc_icons_icon + .sc_icons_item_title + .sc_icons_item_description,
.sc_icons .sc_icons_item_linked .sc_icons_image + .sc_icons_item_description,
.sc_icons .sc_icons_item_linked .sc_icons_image + .sc_icons_item_title + .sc_icons_item_description,
.sc_icons .sc_icons_item_linked .sc_icons_image img {
  -webkit-transition: all 0.25s ease;
  -ms-transition: all 0.25s ease;
  transition: all 0.25s ease;
}

.sc_icons .sc_icons_item_linked .sc_icons_icon + .sc_icons_item_title,
.sc_icons .sc_icons_item_linked .sc_icons_image + .sc_icons_item_title {
  -webkit-transform-origin: center bottom;
  -ms-transform-origin: center bottom;
  transform-origin: center bottom;
}

.sc_icons .sc_icons_item_linked .sc_icons_icon + .sc_icons_item_description,
.sc_icons .sc_icons_item_linked .sc_icons_icon + .sc_icons_item_title + .sc_icons_item_description,
.sc_icons .sc_icons_item_linked .sc_icons_image + .sc_icons_item_description,
.sc_icons .sc_icons_item_linked .sc_icons_image + .sc_icons_item_title + .sc_icons_item_description {
  -webkit-transform-origin: center top;
  -ms-transform-origin: center top;
  transform-origin: center top;
}

.sc_icons .sc_icons_item_linked:hover .sc_icons_image img {
  -webkit-transform: scale(1.1, 1.1);
  -ms-transform: scale(1.1, 1.1);
  transform: scale(1.1, 1.1);
}

.sc_icons .sc_icons_item_linked:hover .sc_icons_icon + .sc_icons_item_title,
.sc_icons .sc_icons_item_linked:hover .sc_icons_image + .sc_icons_item_title,
.sc_icons .sc_icons_item_linked:hover .sc_icons_icon + .sc_icons_item_description,
.sc_icons .sc_icons_item_linked:hover .sc_icons_icon + .sc_icons_item_title + .sc_icons_item_description,
.sc_icons .sc_icons_item_linked:hover .sc_icons_image + .sc_icons_item_description,
.sc_icons .sc_icons_item_linked:hover .sc_icons_image + .sc_icons_item_title + .sc_icons_item_description {
  -webkit-transform: scale(0.9, 0.9);
  -ms-transform: scale(0.9, 0.9);
  transform: scale(0.9, 0.9);
}

@-webkit-keyframes icons-zoom {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
    -webkit-transform: scale(1.75, 1.75);
    -ms-transform: scale(1.75, 1.75);
    transform: scale(1.75, 1.75);
  }
}
@keyframes icons-zoom {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
    -webkit-transform: scale(1.75, 1.75);
    -ms-transform: scale(1.75, 1.75);
    transform: scale(1.75, 1.75);
  }
}

/*# sourceMappingURL=icons.css.map */
