.sp-easy-accordion-popup-content {
    position: absolute;
    z-index: 9999;
    background: #ffffff;
    border-radius: 4px;
    width: fit-content;
    height: fit-content;
    margin: 0;
    // overflow: hidden;
    padding: 0;
    box-sizing: border-box;
    box-shadow: 0px 4px 16px rgb(0 0 0 / 20%);
    margin-top: -12px;
}

.sp-easy-accordion-button {
    .sp-easy-accordion-header-left {
        &.wide-area {
            width: 85%;
            justify-content: space-between;
            align-items: center;

            .sp-easy-accordion-toggle {
                width: 100%;

                .components-toggle-control {
                    margin-bottom: 0px;
                }
            }
        }
    }
}