@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

/* MP Timetable
------------------------------------------------ */

/* Single event */
.post_type_mp-event .timeslot {
	display:block;
	float: left;
	padding: 1em;
	@include box(24%, 100%);
	@include border-box;
	text-align: center;
	border: 1px dotted #ddd;
	background-color:#f7f7f7;
	margin: 0 1% 1% 0;
}
.post_type_mp-event .timeslot .timeslot-link {
	@include font(1.2em, '', 700);
	display:inline-block;
	margin-bottom: 0.5em;
}
.post_type_mp-event .timeslot .timeslot-start,
.post_type_mp-event .timeslot .timeslot-end {
	font-weight: 700;
}
.post_type_mp-event .timeslot .timeslot-description {
	font-style: italic;
	display:inline-block;
	margin-top: 0.5em;
}
.post_type_mp-event .timeslot .timeslot-user {
	display: inline-block;
	margin-top: 0.5em;
}
.post_type_mp-event .timeslot .timeslot-user .avatar {
	display: inline-block;
	vertical-align:middle;
	margin-right: 0.3em;
	@include border-round;
}


/* Single column */
.post_type_mp-column .event-link {
	@include font(1.25em, '', 700);
}
.post_type_mp-column .event-description {
	display:inline-block;
	font-style: italic;
	padding: 0.75em 0;
}
.post_type_mp-column .event-user .avatar {
	display:inline-block;
	margin-right:0.3em;
	vertical-align: middle;
	@include border-round;
}


/* Preview mode in Elementor */
body.elementor-editor-active {
	.mptt-shortcode-wrapper > .mptt-navigation-tabs + table {
		display: table !important;
		width: 100%;
	}
	.mptt-shortcode-wrapper table td {
		height: 1.75em !important;
		padding-top: 1em !important;
		padding-bottom: 1em !important;
	}
}