@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

/* Shortcode: Blogger */
.sc_blogger {
	position: relative;	
	padding-top: 0.0001px;
}

.sc_blogger .trx_addons_loading {
	@include abs-cover(1000);
	background-color: rgba(255,255,255,0.75);
}

.sc_blogger_columns_wrap {
	@include flex;
	@include flex-wrap(wrap);
}

.sc_blogger_slider .sc_blogger_item,
.sc_blogger_columns_wrap .sc_blogger_item {
	display:inline-block;
	vertical-align:top;
	@include box(100%, 100%);
	@include border-box;
}
.sc_blogger_slider .sc_blogger_item {
	margin-bottom: 0 !important;
}
/* To move pagination bullets below items
.sc_blogger .sc_blogger_slider.slider_outer_pagination_pos_bottom {
	padding-bottom: 3em;
}
*/

.sc_blogger .sc_blogger_item_align_left {
	.sc_blogger_item_header,
	.sc_blogger_item_content,
	.sc_blogger_item_footer {
		text-align: left;
	}
}
.sc_blogger .sc_blogger_item_align_center {
	.sc_blogger_item_header,
	.sc_blogger_item_content,
	.sc_blogger_item_footer {
		text-align: center;
	}
}
.sc_blogger .sc_blogger_item_align_right {
	.sc_blogger_item_header,
	.sc_blogger_item_content,
	.sc_blogger_item_footer {
		text-align: right;
	}
}
.sc_blogger.sc_blogger_image_position_alter {
	.sc_blogger_item_odd.sc_blogger_item_align_right,
	.sc_blogger_item_even.sc_blogger_item_align_left {
		.sc_blogger_item_header,
		.sc_blogger_item_content,
		.sc_blogger_item_footer {
			text-align: right;
		}
	}
	.sc_blogger_item_odd.sc_blogger_item_align_left,
	.sc_blogger_item_even.sc_blogger_item_align_right {
		.sc_blogger_item_header,
		.sc_blogger_item_content,
		.sc_blogger_item_footer {
			text-align: left;
		}
	}
}

.sc_blogger .sc_blogger_item_header {
	margin-bottom: 1em;
}
.sc_blogger .sc_blogger_item_title {
	margin:0;
}
.sc_blogger .sc_blogger_post_meta {
	@include font(0.9286em, 1.5em, 400, italic);
	margin-top: 0.4em;
}
.sc_blogger .sc_blogger_item_featured {
	margin-bottom:0;

	&[class*="hover_"] {
		display: block;
	}
	img {
		min-width: 100%;
		height: auto;
	}
	.post_meta_label {
		display: none;
	}
	.sc_blogger_item_link {
		@include abs-cover(2);
	}
}
.sc_blogger {
	.sc_blogger_item_featured,
	.post_featured {
		.trx_addons_video_player {
			max-width: 100%;
		}
	}
}
.sc_blogger .post_meta_categories {
	margin: 0 0 0.5em;
}
.sc_blogger .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger .sc_blogger_item_meta + .sc_blogger_item_excerpt {
	margin-top: 1em;
}
.sc_blogger .sc_blogger_item_excerpt_text {
	max-height: 8em;
	line-height:1.6em;
	overflow:hidden;
}
.sc_blogger .sc_blogger_item_excerpt_text p {
	margin:0;
}
.sc_blogger .sc_blogger_item.post_format_quote .sc_blogger_item_excerpt_text {
	max-height: none;
}
.sc_blogger .sc_blogger_item_excerpt_text + p,
.sc_blogger .sc_blogger_item_excerpt_text + a {
	margin: 1.5em 0 0;
}
.sc_blogger .sc_blogger_item blockquote {
	margin: 1em 0;
}
.sc_blogger .sc_blogger_item blockquote p {
	@include font(1em, 1.5em, inherit);
}
.sc_blogger .sc_blogger_item_title + .sc_blogger_item_button,
.sc_blogger .sc_blogger_item_meta + .sc_blogger_item_button,
.sc_blogger .sc_blogger_item_excerpt + .sc_blogger_item_button {
	margin-top:1em;
}
.sc_blogger .more-link {
	background-color: transparent;
}
.sc_blogger .sc_blogger_item_footer {
	margin-top: 1em;
}


/* Type: Default
---------------------------------------------------------- */
.sc_blogger_content .sc_blogger_item_default + .sc_blogger_item_default {
	margin-top: 2em;
}

.sc_blogger_item_default.sc_blogger_item_image_position_top .sc_blogger_item_featured + .sc_blogger_item_content {
	margin-top: 1em;
}
.sc_blogger_item_default.sc_blogger_item_image_position_left .sc_blogger_item_body,
.sc_blogger_item_default.sc_blogger_item_image_position_right .sc_blogger_item_body,
.sc_blogger_item_default.sc_blogger_item_image_position_alter .sc_blogger_item_body {
	overflow:hidden;
	@include flex;
	@include flex-direction(row);
	@include flex-wrap(nowrap);
	@include flex-align-items(center);
}
.sc_blogger_item_default.sc_blogger_item_image_position_left .sc_blogger_item_content,
.sc_blogger_item_default.sc_blogger_item_image_position_alter.sc_blogger_item_odd .sc_blogger_item_content {
	padding-left: 2em;
	@include border-box;
}
.sc_blogger_item_default.sc_blogger_item_image_position_right .sc_blogger_item_featured,
.sc_blogger_item_default.sc_blogger_item_image_position_alter.sc_blogger_item_even .sc_blogger_item_featured {
	order: 2;
}
.sc_blogger_item_default.sc_blogger_item_image_position_right .sc_blogger_item_content,
.sc_blogger_item_default.sc_blogger_item_image_position_alter.sc_blogger_item_even .sc_blogger_item_content {
	padding-right: 2em;
	@include border-box;
}

.sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_body {
	background-color: #f7f7f7;
}
.sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content {
	padding: 1.5em;
}
.sc_blogger_item_default.sc_blogger_item_on_plate.sc_blogger_item_image_position_top .sc_blogger_item_featured + .sc_blogger_item_content {
	margin-top: 0;
}
.sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_excerpt {
	overflow: hidden;
	position: relative;
}
.sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_excerpt:after {
	content: ' ';
	@include abs-lb;
	width: 100%;
	height: 2em;
	background-image: -webkit-gradient(linear,left top,left bottom,from(rgba(255,255,255,0)),to(#f7f7f7));
	background-image: -webkit-linear-gradient(top,rgba(255,255,255,0),#f7f7f7);
	background-image: -o-linear-gradient(top,rgba(255,255,255,0),#f7f7f7);
	background-image: linear-gradient(180deg,rgba(255,255,255,0),#f7f7f7);	
}
.sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_content .sc_blogger_item_excerpt,
.sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_masonry_wrap .sc_blogger_item_excerpt {
	height: unset;
	overflow: unset;
}
.sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_content .sc_blogger_item_excerpt:after,
.sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_masonry_wrap .sc_blogger_item_excerpt:after {
	display: none;
}
.sc_blogger_item_default.sc_blogger_item_on_plate.sc_blogger_item_image_position_left .sc_blogger_item_body,
.sc_blogger_item_default.sc_blogger_item_on_plate.sc_blogger_item_image_position_right .sc_blogger_item_body,
.sc_blogger_item_default.sc_blogger_item_on_plate.sc_blogger_item_image_position_alter .sc_blogger_item_body {
	height: 100%;

	.sc_blogger_item_featured {
		@include flex-align-self(stretch);
	}
}


/* Type: Wide
---------------------------------------------------------- */
.sc_blogger_content .sc_blogger_item_wide {
	margin-bottom: 2em;
	padding-bottom: 2em;
	border-bottom: 1px solid #ddd;
}
.sc_blogger_content .sc_blogger_item_wide:last-child {
	margin-bottom: 0;
	padding-bottom: 0;
	border-bottom: none;
}

.sc_blogger_item_wide {
	overflow:hidden;
	@include flex;
	@include flex-direction(row);
	@include flex-wrap(nowrap);
	@include flex-align-items(flex-start);
}
.sc_blogger_item_wide .sc_blogger_item_header {
	margin-bottom: 0;
}
.sc_blogger_item_wide .sc_blogger_item_header,
.sc_blogger_item_wide .sc_blogger_item_body {
	//@include flex-basis(50%);
	width: 50%;
}
.sc_blogger_item_wide .sc_blogger_item_header,
.sc_blogger_item_wide .sc_blogger_item_content {
	@include border-box;	
}
.sc_blogger_item_wide .sc_blogger_item_content {
	padding-left: 2em;
}

.sc_blogger_item_wide.sc_blogger_item_with_image .sc_blogger_item_header {
	//@include flex-basis(30%);
	width: 30%;
}
.sc_blogger_item_wide.sc_blogger_item_with_image .sc_blogger_item_body {
	//@include flex-basis(70%);
	width: 70%;
	@include flex;
	@include flex-direction(row);
	@include flex-wrap(nowrap);
	@include flex-align-items(flex-start);
}
.sc_blogger_item_wide.sc_blogger_item_with_image .sc_blogger_item_featured {
	//@include flex-basis(40%);
	width: 40%;
}
.sc_blogger_item_wide.sc_blogger_item_with_image .sc_blogger_item_content {
	//@include flex-basis(60%);
	width: 60%;
}
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_no_excerpt .sc_blogger_item_header {
	width: 70%;
}
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_no_excerpt .sc_blogger_item_body {
	width: 30%;
}
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_no_excerpt .sc_blogger_item_featured {
	width: 100% !important;
}
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_top .sc_blogger_item_header {
	order: 2;
}
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_top .sc_blogger_item_header,
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_top .sc_blogger_item_content {
	padding-left: 2em;
}
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_left .sc_blogger_item_header,
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_right .sc_blogger_item_header,
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_alter .sc_blogger_item_header {
	padding-right: 2em;	
}
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_left .sc_blogger_item_content,
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_alter.sc_blogger_item_odd .sc_blogger_item_content {
	padding-left: 2em;
}
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_right .sc_blogger_item_content,
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_alter.sc_blogger_item_even .sc_blogger_item_content {
	padding-left: 0;
	padding-right: 2em;
}
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_right .sc_blogger_item_featured,
.sc_blogger_item_wide.sc_blogger_item_with_image.sc_blogger_item_image_position_alter.sc_blogger_item_even .sc_blogger_item_featured {
	order: 2;
}

.sc_blogger_item_wide.sc_blogger_item_on_plate {
	padding: 2em;
	border-bottom: none;
	margin-bottom: 2em;
	background-color: #f7f7f7;
}
.sc_blogger_item_wide.sc_blogger_item_on_plate:last-child {
	padding-bottom: 2em;
	margin-bottom: 0;
}



/* Type: List
---------------------------------------------------------- */

/* Common styles */
.sc_blogger_content .sc_blogger_item_list {
	margin-bottom: 1em;
	padding-bottom: 1em;
	border-bottom: 1px solid #ddd;
}
.sc_blogger_content .sc_blogger_item_list:last-child {
	margin-bottom: 0;
	padding-bottom: 0;
	border-bottom: none;
}
.sc_blogger_content .sc_blogger_item_list.sc_blogger_item_image_position_top + .sc_blogger_item_list.sc_blogger_item_image_position_top {
	margin-top: 2em;
	padding-top: 0;
	border-top: none;
}

.sc_blogger_item_list.sc_blogger_item_image_position_top .sc_blogger_item_featured + .sc_blogger_item_content {
	margin-top: 1em;
}

.sc_blogger_item_list .sc_blogger_item_meta .post_meta_number {
	margin-right: 0;
}
.sc_blogger_item_list .sc_blogger_item_meta .post_meta_label {
	display: none;
}

/* On plate */
.sc_blogger_content .sc_blogger_item_list.sc_blogger_item_on_plate + .sc_blogger_item_list.sc_blogger_item_on_plate {
	padding-top: 0;
	border-top: none;
}
.sc_blogger_item_list.sc_blogger_item_on_plate .sc_blogger_item_body {
	background-color: #f7f7f7;
}
.sc_blogger_item_list.sc_blogger_item_on_plate .sc_blogger_item_content {
	padding: 1em;
}
.sc_blogger_item_list.sc_blogger_item_on_plate.sc_blogger_item_image_position_top .sc_blogger_item_featured + .sc_blogger_item_content {
	margin-top: 0;
}

/* With numbers */
.sc_blogger_item_list.sc_blogger_item_with_numbers:not(.sc_blogger_item_with_image) .sc_blogger_item_content > * {
	padding-left: 2rem;
}
.sc_blogger_item_list.sc_blogger_item_with_numbers:not(.sc_blogger_item_with_image) .sc_blogger_item_title {
	position: relative;
}
.sc_blogger_item_list.sc_blogger_item_with_numbers:not(.sc_blogger_item_with_image) .sc_blogger_item_title:before,
.sc_blogger_item_list.sc_blogger_item_with_numbers.sc_blogger_item_with_image .sc_blogger_item_featured:after {
	content: attr(data-item-number);
	display: block;
	@include square(1.5em);
	@include border-round;
	background-color: #333;
	color: #fff;
	@include font(10px, 15px);
}
.sc_blogger_item_list.sc_blogger_item_with_numbers:not(.sc_blogger_item_with_image) .sc_blogger_item_title:before {
	@include abs-lc(0, 2);
}
.sc_blogger_item_list.sc_blogger_item_with_numbers.sc_blogger_item_with_image .sc_blogger_item_featured {
	overflow: visible;

	&:hover {
		img, .post_thumb, .trx_addons_secondary_image {
			@include transform-none;
		}
	}
}
.sc_blogger_item_list.sc_blogger_item_with_numbers.sc_blogger_item_with_image.sc_blogger_item_image_position_left .sc_blogger_item_featured:after,
.sc_blogger_item_list.sc_blogger_item_with_numbers.sc_blogger_item_with_image.sc_blogger_item_image_position_alter.sc_blogger_item_even .sc_blogger_item_featured:after {
	@include abs-lc(-0.75em, 3);
}
.sc_blogger_item_list.sc_blogger_item_with_numbers.sc_blogger_item_with_image.sc_blogger_item_image_position_right .sc_blogger_item_featured:after,
.sc_blogger_item_list.sc_blogger_item_with_numbers.sc_blogger_item_with_image.sc_blogger_item_image_position_alter.sc_blogger_item_odd .sc_blogger_item_featured:after {
	@include abs-rc(-0.75em, 3);
}

/* With image */
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_left .sc_blogger_item_body,
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_right .sc_blogger_item_body,
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_alter .sc_blogger_item_body {
	@include flex;
	@include flex-direction(row);
	@include flex-wrap(nowrap);
	@include flex-align-items(flex-start);
}
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_left .sc_blogger_item_content,
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_alter.sc_blogger_item_odd .sc_blogger_item_content {
	padding-left: 1em;
	@include border-box;
}
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_right .sc_blogger_item_featured,
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_alter.sc_blogger_item_even .sc_blogger_item_featured {
	order: 2;
}
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_right .sc_blogger_item_content,
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_alter.sc_blogger_item_even .sc_blogger_item_content {
	padding-right: 1em;
	@include border-box;
}



/* Type: News
---------------------------------------------------------- */

.sc_blogger_grid_wrap {
	display: grid;
}
@media all and (-ms-high-contrast:none) {
	.sc_blogger_grid_wrap {
		display: -ms-grid;
	}
}

.sc_blogger_grid_wrap .sc_blogger_item + .sc_blogger_item {
	margin-top: 0;
}

.sc_blogger_grid_1 {
	display: block;
}
.sc_blogger_grid_wrap .sc_item_featured [class*="post_info_"] .entry-title {
	font-size: 1.15em;
}

/* Layout: Announces */
.sc_blogger_news_announce {

	.sc_blogger_grid_wrap .sc_blogger_item_body,
	.sc_blogger_grid_wrap .sc_blogger_item_featured {
		height: 100%;
		width: 100%;
	}

	.sc_blogger_grid_2 {
		grid-template-columns: 1fr 1fr;
		grid-template-rows: 36em;
	}
	.sc_blogger_grid_2 .sc_blogger_item:nth-child(2n+1) {
		grid-column: 1;
		grid-row: 1;
	}
	.sc_blogger_grid_2 .sc_blogger_item:nth-child(2n+2) {
		grid-column: 2;
		grid-row: 1;
	}
@media all and (-ms-high-contrast:none) {
	.sc_blogger_grid_2 {
		-ms-grid-columns: 1fr 1fr;
		-ms-grid-rows: 36em;
	}
	.sc_blogger_grid_2 .sc_blogger_item:nth-child(2n+1) {
		-ms-grid-column: 1;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_2 .sc_blogger_item:nth-child(2n+2) {
		-ms-grid-column: 2;
		-ms-grid-row: 1;
	}
}

	.sc_blogger_grid_3 {
		grid-template-columns: 1fr 1fr;
		grid-template-rows: 18em 18em;
	}
	.sc_blogger_grid_3 .sc_blogger_item:nth-child(3n+1) {
		grid-column: 1;
		grid-row: 1 / 3;
	}
	.sc_blogger_grid_3 .sc_blogger_item:nth-child(3n+2) {
		grid-column: 2;
		grid-row: 1;
	}
	.sc_blogger_grid_3 .sc_blogger_item:nth-child(3n+3) {
		grid-column: 2;
		grid-row: 2;
	}
@media all and (-ms-high-contrast:none) {
	.sc_blogger_grid_3 {
		-ms-grid-columns: 1fr 1fr;
		-ms-grid-rows: 18em 18em;
	}
	.sc_blogger_grid_3 .sc_blogger_item:nth-child(3n+1) {
		-ms-grid-column: 1;
		-ms-grid-row: 1;
		-ms-grid-row-span: 2;
	}
	.sc_blogger_grid_3 .sc_blogger_item:nth-child(3n+2) {
		-ms-grid-column: 2;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_3 .sc_blogger_item:nth-child(3n+3) {
		-ms-grid-column: 2;
		-ms-grid-row: 2;
	}
}

	.sc_blogger_grid_4 {
		grid-template-columns: 1fr 1fr 1fr 1fr;
		grid-template-rows: 18em 18em;
	}
	.sc_blogger_grid_4 .sc_blogger_item:nth-child(4n+1) {
		grid-column: 1 / 3;
		grid-row: 1 / 3;
	}
	.sc_blogger_grid_4 .sc_blogger_item:nth-child(4n+2) {
		grid-column: 3 / 5;
		grid-row: 1;
	}
	.sc_blogger_grid_4 .sc_blogger_item:nth-child(4n+3) {
		grid-column: 3;
		grid-row: 2;
	}
	.sc_blogger_grid_4 .sc_blogger_item:nth-child(4n+4) {
		grid-column: 4;
		grid-row: 2;
	}
@media all and (-ms-high-contrast:none) {
	.sc_blogger_grid_4 {
		-ms-grid-columns: 1fr 1fr 1fr 1fr;
		-ms-grid-rows: 18em 18em;
	}
	.sc_blogger_grid_4 .sc_blogger_item:nth-child(4n+1) {
		-ms-grid-column: 1;
		-ms-grid-column-span: 2;
		-ms-grid-row: 1;
		-ms-grid-row-span: 2;
	}
	.sc_blogger_grid_4 .sc_blogger_item:nth-child(4n+2) {
		-ms-grid-column: 3;
		-ms-grid-column-span: 2;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_4 .sc_blogger_item:nth-child(4n+3) {
		-ms-grid-column: 3;
		-ms-grid-row: 2;
	}
	.sc_blogger_grid_4 .sc_blogger_item:nth-child(4n+4) {
		-ms-grid-column: 4;
		-ms-grid-row: 2;
	}
}

	.sc_blogger_grid_5 {
		grid-template-columns: 1fr 1fr 1fr 1fr;
		grid-template-rows: 18em 18em;
	}
	.sc_blogger_grid_5 .sc_blogger_item:nth-child(5n+1) {
		grid-column: 1 / 3;
		grid-row: 1 / 3;
	}
	.sc_blogger_grid_5 .sc_blogger_item:nth-child(5n+2) {
		grid-column: 3;
		grid-row: 1;
	}
	.sc_blogger_grid_5 .sc_blogger_item:nth-child(5n+3) {
		grid-column: 4;
		grid-row: 1;
	}
	.sc_blogger_grid_5 .sc_blogger_item:nth-child(5n+4) {
		grid-column: 3;
		grid-row: 2;
	}
	.sc_blogger_grid_5 .sc_blogger_item:nth-child(5n+5) {
		grid-column: 4;
		grid-row: 2;
	}
@media all and (-ms-high-contrast:none) {
	.sc_blogger_grid_5 {
		-ms-grid-columns: 1fr 1fr 1fr 1fr;
		-ms-grid-rows: 18em 18em;
	}
	.sc_blogger_grid_5 .sc_blogger_item:nth-child(5n+1) {
		-ms-grid-column: 1;
		-ms-grid-column-span: 2;
		-ms-grid-row: 1;
		-ms-grid-row-span: 2;
	}
	.sc_blogger_grid_5 .sc_blogger_item:nth-child(5n+2) {
		-ms-grid-column: 3;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_5 .sc_blogger_item:nth-child(5n+3) {
		-ms-grid-column: 4;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_5 .sc_blogger_item:nth-child(5n+4) {
		-ms-grid-column: 3;
		-ms-grid-row: 2;
	}
	.sc_blogger_grid_5 .sc_blogger_item:nth-child(5n+5) {
		-ms-grid-column: 4;
		-ms-grid-row: 2;
	}
}

	.sc_blogger_grid_6 {
		grid-template-columns: 1fr 1fr 1fr 1fr;
		grid-template-rows: 18em 18em;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+1) {
		grid-column: 1 / 3;
		grid-row: 1;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+2) {
		grid-column: 1 / 3;
		grid-row: 2;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+3) {
		grid-column: 3;
		grid-row: 1;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+4) {
		grid-column: 4;
		grid-row: 1;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+5) {
		grid-column: 3;
		grid-row: 2;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+6) {
		grid-column: 4;
		grid-row: 2;
	}
@media all and (-ms-high-contrast:none) {
	.sc_blogger_grid_6 {
		-ms-grid-columns: 1fr 1fr 1fr 1fr;
		-ms-grid-rows: 18em 18em;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+1) {
		-ms-grid-column: 1;
		-ms-grid-column-span: 2;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+2) {
		-ms-grid-column: 1;
		-ms-grid-column-span: 2;
		-ms-grid-row: 2;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+3) {
		-ms-grid-column: 3;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+4) {
		-ms-grid-column: 4;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+5) {
		-ms-grid-column: 3;
		-ms-grid-row: 2;
	}
	.sc_blogger_grid_6 .sc_blogger_item:nth-child(6n+6) {
		-ms-grid-column: 4;
		-ms-grid-row: 2;
	}
}

	.sc_blogger_grid_7 {
		grid-template-columns: 1fr 1fr 1fr 1fr;
		grid-template-rows: 18em 18em;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+1) {
		grid-column: 1 / 3;
		grid-row: 1;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+2) {
		grid-column: 1;
		grid-row: 2;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+3) {
		grid-column: 2;
		grid-row: 2;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+4) {
		grid-column: 3;
		grid-row: 1;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+5) {
		grid-column: 4;
		grid-row: 1;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+6) {
		grid-column: 3;
		grid-row: 2;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+7) {
		grid-column: 4;
		grid-row: 2;
	}
@media all and (-ms-high-contrast:none) {
	.sc_blogger_grid_7 {
		-ms-grid-columns: 1fr 1fr 1fr 1fr;
		-ms-grid-rows: 18em 18em;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+1) {
		-ms-grid-column: 1;
		-ms-grid-column-span: 2;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+2) {
		-ms-grid-column: 1;
		-ms-grid-row: 2;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+3) {
		-ms-grid-column: 2;
		-ms-grid-row: 2;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+4) {
		-ms-grid-column: 3;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+5) {
		-ms-grid-column: 4;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+6) {
		-ms-grid-column: 3;
		-ms-grid-row: 2;
	}
	.sc_blogger_grid_7 .sc_blogger_item:nth-child(7n+7) {
		-ms-grid-column: 4;
		-ms-grid-row: 2;
	}
}

	.sc_blogger_grid_8 {
		grid-template-columns: 1fr 1fr 1fr 1fr;
		grid-template-rows: 18em 18em;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+1) {
		grid-column: 1;
		grid-row: 1;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+2) {
		grid-column: 2;
		grid-row: 1;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+3) {
		grid-column: 3;
		grid-row: 1;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+4) {
		grid-column: 4;
		grid-row: 1;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+5) {
		grid-column: 1;
		grid-row: 2;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+6) {
		grid-column: 2;
		grid-row: 2;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+7) {
		grid-column: 3;
		grid-row: 2;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+8) {
		grid-column: 4;
		grid-row: 2;
	}
@media all and (-ms-high-contrast:none) {
	.sc_blogger_grid_8 {
		-ms-grid-columns: 1fr 1fr 1fr 1fr;
		-ms-grid-rows: 18em 18em;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+1) {
		-ms-grid-column: 1;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+2) {
		-ms-grid-column: 2;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+3) {
		-ms-grid-column: 3;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+4) {
		-ms-grid-column: 4;
		-ms-grid-row: 1;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+5) {
		-ms-grid-column: 1;
		-ms-grid-row: 2;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+6) {
		-ms-grid-column: 2;
		-ms-grid-row: 2;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+7) {
		-ms-grid-column: 3;
		-ms-grid-row: 2;
	}
	.sc_blogger_grid_8 .sc_blogger_item:nth-child(8n+8) {
		-ms-grid-column: 4;
		-ms-grid-row: 2;
	}
}

}

/* Layout: Magazine */
.sc_blogger_news_magazine {

	.sc_blogger_grid_wrap {
		display: block;
		overflow: hidden;
	}
	.sc_blogger_grid_wrap:not([class*="sc_blogger_grid_columns_"]) .sc_blogger_item:first-child,
	.sc_blogger_grid_wrap[class*="sc_blogger_grid_columns_"] .sc_blogger_item:last-child {
		padding-bottom: 1em;
		margin-bottom: 1em;
		border-bottom: 1px solid #ddd;
	}
	.sc_blogger_grid_wrap:not([class*="sc_blogger_grid_columns_"]) .sc_blogger_item:last-child,
	.sc_blogger_grid_wrap.sc_blogger_grid_columns_2 .sc_blogger_item:last-child {
		padding-bottom: 0;
		margin-bottom: 0;
		border-bottom: none;
	}
	.sc_blogger_grid_wrap[class*="sc_blogger_grid_columns_"] .sc_blogger_item {
		float: left;
		width: 31%;
	}
	.sc_blogger_grid_wrap[class*="sc_blogger_grid_columns_"] .sc_blogger_item:first-child,
	.sc_blogger_grid_wrap.sc_blogger_grid_columns_3 .sc_blogger_item:nth-child(2n+2) {
		margin-right: 3.5%;
	}
	.sc_blogger_grid_wrap.sc_blogger_grid_columns_2 .sc_blogger_item:first-child {
		width: 65.5%;
	}

}



/* Type: Panel
---------------------------------------------------------- */
.sc_blogger_panel {
	--sc-blogger-panel-text: #fff;
	--sc-blogger-panel-text-link: #fff;
	--sc-blogger-panel-text-hover: #eaeaea;

	.sc_blogger_columns_wrap,
	.sc_item_posts_container {
		margin-left: 0;
		margin-right: 0;
		position: relative;

		[class*="trx_addons_column-"] {
			padding: 0 !important;
		}
	}
	.sc_blogger_item {
		position: relative;
		z-index: 2;
		padding: 20em 2em 2em;
		color: var(--sc-blogger-panel-text);

		a {
			color: var(--sc-blogger-panel-text-link);
		}
		a:hover {
			color: var(--sc-blogger-panel-text-hover);
		}
		.sc_blogger_item_title {
			a {
				color: var(--sc-blogger-panel-text-link);
			}
			a:hover {
				color: var(--sc-blogger-panel-text-hover);
			}
		}
		.sc_blogger_item_button {
			margin-top: 1em;
			opacity: 0;

			.sc_button.sc_button_simple:not(.sc_button_bg_image) {
				color: var(--sc-blogger-panel-text-link);

				&:hover {
					color: var(--sc-blogger-panel-text-hover);
				}
			}
		}
		.sc_blogger_item_title,
		.sc_blogger_item_meta,
		.sc_blogger_item_excerpt,
		.sc_blogger_item_button {
			@include translateY(30px);
			@include transition-properties(transform,opacity);
		}
		&:hover .sc_blogger_item_title,
		&:hover .sc_blogger_item_meta,
		&:hover .sc_blogger_item_excerpt {
			@include translateY(-30px);
		}
		&:hover .sc_blogger_item_button {
			@include translateY(0);
			opacity: 1;
		}
	}
	.sc_blogger_item + .sc_blogger_item,
	[class*="trx_addons_column-"] + [class*="trx_addons_column-"] .sc_blogger_item {
		border-left: 1px solid rgba(255,255,255,0.2);
	}

	.sc_blogger_panel_thumbs {
		@include abs-cover(0);
		background-color: #f0f0f0;

		&:before {
			content: ' ';
			display: block;
			@include abs-cover(1);
			@include bg-mask(#000, 0.2);
		}

		.sc_panel_thumb {
			@include abs-cover(0);
			@include bg-cover;
			@include transition-properties(opacity, 0.5s);
			opacity: 0;
			pointer-events: none;

			.trx_addons_video_player {
				@include abs-cover(0);

				.video_frame {
					@include abs-cover(0);
					@include flex;
					@include flex-align-items(center);
					@include flex-justify-content(center);
					overflow: hidden;

					.video_frame_controls {
						display: none;
					}
				}
			}
		}
		.sc_panel_thumb_active {
			opacity: 1;
		}
	}
}


/* Type: Cards
---------------------------------------------------------- */
.sc_blogger_cards {
	@include flex;
	@include flex-direction(row);
	@include flex-justify-content(flex-start);
	@include flex-align-items(stretch);
	@include flex-wrap(nowrap);
}
.sc_blogger_cards_header {
	@include flex;
	@include flex-direction(column);
	@include flex-justify-content(flex-end);
	@include flex-align-items(flex-start);
	@include flex-shrink(0);
	@include flex-grow(0);
	width: 25%;
	margin: 2em 1em 0 0;
	position: relative;
	padding: 1.5rem;

	.sc_blogger_cards.sc_item_filters_tabs_top &,
	.sc_blogger_cards.sc_item_filters_tabs_left & {
		margin-top: 0;
	}
	& > * {
		position: relative;
		z-index: 2;
		color:  #fff;
	}

	&:before {
		content: " ";
		@include abs-cover;
		@include border-radius(12px);
		background: linear-gradient(130deg,#ff7a18,#af002d 41.07%,#319197 76.05%);
	}
	&:after {
		content: " ";
		@include abs-lt(5px, 5px);
		@include border-radius(8px);
		@include box(calc(100% - 10px), calc(100% - 10px));
		background: #000;
	}
}
.sc_blogger_cards_content {
	@include flex;
	@include flex-direction(column);
	@include flex-justify-content(stretch);
	@include flex-align-items(stretch);
	@include flex-shrink(0);
	@include flex-grow(0);
	position: relative;
	max-width: 100%;

	.sc_blogger_cards_header + & {
		width: calc(75% - 1em);
	}

	&:after {
		content: " ";
		@include abs-rt(0,2em,100);
		bottom: 2.75em;
		width: 5px;
		background: linear-gradient(130deg,#ff7a18,#af002d 41.07%,#319197 76.05%);
		@include box-shadow(-10px 0 20px 3px #000);
	}
	.sc_blogger_cards.sc_item_filters_tabs_top &:after,
	.sc_blogger_cards.sc_item_filters_tabs_left &:after {
		display: none;
	}

	.sc_item_filters {
		margin: 0 0 0 1.5em;
	}

	.sc_blogger_content {
		@include flex;
		@include flex-direction(row);
		@include flex-justify-content(flex-start);
		@include flex-align-items(stretch);
		@include flex-shrink(0);
		@include flex-grow(0);
		scrollbar-color: #666 #201c29;
		scrollbar-gutter: always;
		padding: 2em 0 1.5em 2em;
		margin: 0;
		overflow-x: scroll;
		-webkit-overflow-scrolling: touch;
	}
	.sc_blogger_item {
		padding: 1.5em;
		border-radius: 16px;
		overflow: hidden;
		background: linear-gradient(85deg,#434343,#262626);
		color: #fff;
		@include flex;
		@include flex-direction(column);
		@include transition(transform .3s ease-out, margin .3s ease-out);
		margin: 0;
		min-width: 280px;
		min-height: 320px;
		@include box-shadow(-1.5em 0 2em -2em #000);
		position: relative;
		z-index: 1;
	}
	.sc_blogger_item:nth-child(2) { z-index: 2; }
	.sc_blogger_item:nth-child(3) { z-index: 3; }
	.sc_blogger_item:nth-child(4) { z-index: 4; }
	.sc_blogger_item:nth-child(5) { z-index: 5; }
	.sc_blogger_item:nth-child(6) { z-index: 6; }
	.sc_blogger_item:nth-child(7) { z-index: 7; }
	.sc_blogger_item:nth-child(8) { z-index: 8; }
	.sc_blogger_item:nth-child(9) { z-index: 9; }
	.sc_blogger_item:nth-child(10) { z-index: 10; }
	.sc_blogger_item:nth-child(11) { z-index: 11; }
	.sc_blogger_item:nth-child(12) { z-index: 12; }

	.sc_blogger_item:not(:first-child) {
		margin-left: -100px;
		@include box-shadow(-3em 0 3em -2em #000);
	}
//	.sc_blogger_item:focus-within,
	.sc_blogger_item:hover {
    	@include transform(translateY(-1rem) rotate(3deg));

    	& + .sc_blogger_item {
    		margin-left: 0;
    	}
	}
	.sc_blogger_item_content {
		margin-bottom: 2.5em;
	}
	.sc_blogger_item_featured {
		margin-bottom: 1em;
	}
	.sc_blogger_item_title a {
		color: #fff;
	}
	.sc_blogger_item_meta {
		display: inline-block;
		vertical-align: top;
		margin: 0 1em 0 0;
	}
	.sc_blogger_item_footer {
		@include abs-lb(1.5em, 1.5em);
		margin: 0;
	}
}
.sc_blogger_cards_featured {
	.sc_blogger_item {
		padding: 0;
	}
	.post_featured {
		margin: 0;
	}
}